@@ -426,7 +426,7 @@ function attachmentGrid(sContainerId,nId,nFolder,sModule,oDialog)
 				AjaxRoot + "/attachment/" + Self.selectedFilename + "?action=document&session="
 					+ session + "&attached=" + Self.nItemId  + "&module=1&folder="
 					+ activefolder + "&id=" + Self.selectedId;
-				newWindow(sURL, getWindowOptions());
+				newWindow(sURL, getWindowOptions(null, null, "scrollbars=yes"));
 	};
 	this.saveAttachedFile = function() {
 
