@@ -80,14 +80,17 @@ AutoComplete.prototype.onTextChange = function(evt) {
 						parent.AutoComplete.clear();
 					}
 				},50);
-			break;
-	}	
+			return;
+	}
+    if (this.AutoComplete.visible) stopEvent(evt);
 }
 
 AutoComplete.prototype.onDivMouseDown = function() {
 	var st = this.AutoComplete.oText.scrollTop;
 	this.AutoComplete.oText.value = replaceCurrStr(this.AutoComplete.oText.value, this.AutoComplete.oText,this.getAttribute("oval"));
 	setSelRange(this.AutoComplete.oText, this.AutoComplete.oText.value.length, this.AutoComplete.oText.value.length, st);
+	this.AutoComplete.clear();
+	return true;
 }
 
 AutoComplete.prototype.onDivMouseOver = function() {
@@ -145,6 +148,7 @@ AutoComplete.prototype.clear = function () {
 	this.oDiv.style.visibility = "hidden";	
 	this.currSelected = 0;
 	this.currEntries = 0;
+    this.visible = false;
 }
 
 AutoComplete.prototype.enableDiv = function() {
@@ -153,6 +157,7 @@ AutoComplete.prototype.enableDiv = function() {
 	this.oDiv.style.left = getAbsolutePositionLeft(this.oText) + "px";		
 	this.oDiv.scrollTop = "0";
 	this.oDiv.style.visibility = "visible";
+    this.visible = true;
 }
 
 AutoComplete.prototype.onchange = function(txt) {	
@@ -243,19 +248,29 @@ AutoComplete.prototype.search = function(str) {
 		parent.enableDiv();
 		
 		// fire-up search
-        var pattern = "*" + str + "*";
-		var dao = { display_name: pattern, email1: pattern, 
-			email2: pattern, email3: pattern, last_name: pattern,
-            first_name: pattern, emailAutoComplete: true };
+        var pattern = str + "*";		
         
         // in which folder should be searched for autocomplete
-		var allFolder = "folder=6," + configGetKey("folder.contacts");
+		var allFolder = [6, configGetKey("folder.contacts")];
 		if (configGetKey("modules.mail.contactCollectFolder")){
-        	allFolder +=  ","+configGetKey("modules.mail.contactCollectFolder");
+        	allFolder.push(configGetKey("modules.mail.contactCollectFolder"));
         }
-            
+		
+		var dao = { display_name: pattern, email1: pattern, 
+					email2: pattern, email3: pattern, last_name: pattern,
+					first_name: pattern, folder: allFolder, orSearch: true, 
+					emailAutoComplete: true };
+		
+		// hack to hide the global address book
+		// use this with care! will be removed with upcomming releases!
+		if (new Boolean(configGetKey("modules.contacts.hideGlobalAddressBook")) == true &&
+			configGetKey("modules.infostore.module") == false) {
+			dao.folder = allFolder.splice(1);
+			delete(dao.emailAutoComplete);
+		}		
+
 		new JSON().put(AjaxRoot + "/contacts?session=" + session + 
-			"&action=search&emailAutoComplete=true&columns=1,500,555,556,557,524,602,592&sort=609&" + allFolder,
+			"&action=search&columns=1,500,555,556,557,524,602,592&sort=609",
 			dao, null,
 			function(cb) {
 				if (cb && cb.data) {					
@@ -338,7 +353,8 @@ function getParsedNode (str, oStr, oDiv) {
 	   oDiv.appendChild(document.createTextNode(oStr.substring(lIndex,mpos.index)));
 	   lIndex = mpos.index + str.length;
 	   // match
-	   var mn = tmp_span.cloneNode(true);	   
+	   var mn = tmp_span.cloneNode(true);
+	   
 	   mn.firstChild.nodeValue = oStr.substring(mpos.index, lIndex)
 	   oDiv.appendChild(mn);
 	}
