@@ -56,7 +56,9 @@ function register_Calendar() {
 		menuclearSearch();
 	});
 	registerView("calendar/calendar/day",
-		function() { showNode("calendarWorkweek"); }, 
+		function() { 
+			showNode("calendarWorkweek"); 
+		}, 
 		function() { 
 			maxappointmentsperday=configGetKey("gui.calendar.day.numberofappointments");
 			cwwdaysinweek = 1;
@@ -72,11 +74,15 @@ function register_Calendar() {
 			showCalendarWorkweek();
 			register("OX_Add_Flag", calendarAddTag);
 			if (calendarhovers["daywwcustom"] && configGetKey("gui.effects.hover.calendar")) {
-				calendarhovers["daywwcustom"].enable(); calendarhovers["daywwcustom2"].enable(); 
+				calendarhovers["daywwcustom"].enable();
+				calendarhovers["daywwcustom2"].enable(); 
 			}			
 		 }, 
 		 function() {
-		 	if(calendarhovers["daywwcustom"]) { calendarhovers["daywwcustom"].disable(); calendarhovers["daywwcustom2"].disable(); }
+		 	if (calendarhovers["daywwcustom"]) { 
+		 		calendarhovers["daywwcustom"].disable(); 
+		 		calendarhovers["daywwcustom2"].disable(); 
+		 	}
 		 	unregister("OX_Create_Object",default_calendar_workweek_create_object);		 	
  			register("OX_Create_Object",default_calendar_create_object);
  			cwwdisable();
@@ -108,7 +114,10 @@ function register_Calendar() {
 			displayNameDayView();		
  			cwwenable();
 			showCalendarWorkweek();		
-			if(calendarhovers["daywwcustom"] && configGetKey("gui.effects.hover.calendar")) { calendarhovers["daywwcustom"].enable(); calendarhovers["daywwcustom2"].enable(); }
+			if(calendarhovers["daywwcustom"] && configGetKey("gui.effects.hover.calendar")) { 
+				calendarhovers["daywwcustom"].enable(); 
+				calendarhovers["daywwcustom2"].enable(); 
+			}
 			register("OX_Add_Flag", calendarAddTag);
 		}, 
 		function() {
@@ -144,11 +153,17 @@ function register_Calendar() {
 			displayNameDayView();		
  			cwwenable();
 			showCalendarWorkweek();
-			if(calendarhovers["daywwcustom"] && configGetKey("gui.effects.hover.calendar")) { calendarhovers["daywwcustom"].enable(); calendarhovers["daywwcustom2"].enable(); }		
+			if (calendarhovers["daywwcustom"] && configGetKey("gui.effects.hover.calendar")) { 
+				calendarhovers["daywwcustom"].enable(); 
+				calendarhovers["daywwcustom2"].enable(); 
+			}		
 			register("OX_Add_Flag", calendarAddTag);
 		 }, 
 		 function() {
- 			if(calendarhovers["daywwcustom"]) { calendarhovers["daywwcustom"].disable(); calendarhovers["daywwcustom2"].disable(); }
+ 			if (calendarhovers["daywwcustom"]) { 
+ 				calendarhovers["daywwcustom"].disable(); 
+ 				calendarhovers["daywwcustom2"].disable(); 
+ 			}
 			unregister("OX_Create_Object",default_calendar_workweek_create_object);		 	
  			register("OX_Create_Object",default_calendar_create_object);
 			cwwdisable()
@@ -179,25 +194,19 @@ function register_Calendar() {
 				calendarhovers["month"]=hover;	
 				hover.setSize(OXAppointmentHover.contentobject.node);
 				hover.getTarget = function (node) {
-					function getNode(actualnode) {
-						if(actualnode.oxcalobj) {
-							return actualnode;
-						}
-						return;
-					}
-					while (node) {
-						var element=getNode(node);
-						if(element) {
-							return element;
-						}
-						node = node.parentNode;
-					}
-					return;
-				}
+                    try {
+    					while (node) {
+    						if(node.oxcalobj) {
+                                return node.parentNode ? node : null;
+                            }
+    						node = node.parentNode;
+    					}
+                    } catch (e) { /*see default implementation*/ }
+                };
 				hover.onShow = function (node) {
 					OXAppointmentHover.actualHover=this;
 					var splitid=node.oxcalobj.split("-");
-					OXAppointmentHover.refillContent(splitid[1],splitid[0],splitid[2]);	
+					return OXAppointmentHover.refillContent(splitid[1],splitid[0],splitid[2]);	
 				} 
 			} 
 			if(configGetKey("gui.effects.hover.calendar") && calendarhovers["month"]) {
@@ -279,18 +288,25 @@ function register_Calendar() {
 		}, 
 		function() { 
 			filldefaultteam();
-			ctd_startContent();
+			ctd_startContent()			
 			register("OX_Refresh", calendarteamdayrefresh);			
 			register("OX_Add_Flag", calendarAddTag);
-		 }, 
-		 function() {
+			if (configGetKey("gui.effects.hover.calendar") && calendarhovers["teamday"]) {
+				calendarhovers["teamday"].enable();
+			}
+		}, 
+		function() {
 		    ctd_leaveContent();	
 			unregister("OX_Refresh", calendarteamdayrefresh);
 		    unregister("OX_Add_Flag", calendarAddTag);
-		 },
+		    if (calendarhovers["teamday"]) {
+				calendarhovers["teamday"].disable();
+			}
+		},
 		function() { 
 			hideNode("calendarTeamDay");
-			$("calendarTeamDay").style.display="none";},
+			$("calendarTeamDay").style.display="none";
+		},
 		function() {
 			displayNameDayView();
 			ctd_startContent();	
@@ -314,10 +330,16 @@ function register_Calendar() {
 			register("OX_Refresh", calendarteamweekrefresh);
 			filldefaultteam();
 			displayNameDayView();
-			loadTeamWeek();			
+			loadTeamWeek();
+			if (configGetKey("gui.effects.hover.calendar") && calendarhovers["teamworkweek"]) {
+				calendarhovers["teamworkweek"].enable();
+			}
 		 }, 
 		 function() {
 		 	unloadTeamWeek();
+		 	if (calendarhovers["teamworkweek"]) {
+				calendarhovers["teamworkweek"].disable();
+			}
 		 },
 		function() { 
 			unregister("OX_Refresh", calendarteamweekrefresh);
@@ -436,8 +458,7 @@ function register_Calendar() {
             }			
 		 }, 
 		 function() {
-		 	calendarFolderPath.clear();
-			//triggerEvent("OX_Delete_Search");		 	
+		 	calendarFolderPath.clear();	 	
 	 		unregister("OX_Delete_Search", calendarDeleteSearch);
 		 },
 		 null
@@ -537,7 +558,21 @@ function register_Calendar() {
 
 	);				
 }
+var ctd_tv_members;
 register("Loaded",function() {
+	// preparing currently selected members for later use in new appointment, see US532
+	register("OX_Teammember_Changed",
+			function(members) { 
+				var _mem = [];
+				for (var i in members) {
+					_mem.push([0, 0, members[i].display_name, 0, members[i].id, 0, 0, members[i].type]);
+				}
+				ctd_tv_members = {};				
+				ctd_tv_members["data"] = _mem;
+				ctd_tv_members["module"] = "contacts";
+			}
+	);
+	
     calendarFolderPath = new FolderPath("calendar");
 
     var ids = ["arrowForCWVOptions", "arrowForCWWVOptions",
@@ -573,9 +608,8 @@ function calendar_printList() {
 }
 
 function default_calendar_create_object(module,folder) {
-	if(module=="calendar") {
+	if (module=="calendar") {
 		var d=new Date();
-//		var myinterval=configGetKey("gui.calendar.interval");
 		var myinterval=15;
 		d.setUTCDate(1);
 		d.setUTCMonth(activeMonth);
@@ -586,25 +620,25 @@ function default_calendar_create_object(module,folder) {
 		if(mymin % myinterval) {
 			mymin=mymin - (mymin % myinterval)+ myinterval;
 		}
-		d.setUTCMinutes(mymin);
-		calendar_createNewAppointment(d,folder,false);	
+		d.setUTCMinutes(mymin);		
+		calendar_createNewAppointment(d, folder, false, 
+				(currentpath2.join("/").match(/^calendar\/team\//) ? ctd_tv_members : null));	
 	}
 }
 
-function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail) {
+function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail) {	
 	var checkfolder;
 	var wholeday=wholeday;
 	var folder_id_tocheck  = (infolder)?infolder:((activefolder)?activefolder:config.folder.calendar);
 	oMainFolderTree.cache.get_folder(folder_id_tocheck,function (checkfolder){
-
 		calendar_createNewAppointmentCb(checkfolder);
 	});
 
-	function calendar_createNewAppointmentCb(myfolder) {
-		if(myfolder.oxfolder.data.module != "calendar"){
+	function calendar_createNewAppointmentCb(myfolder) {		
+		if (myfolder.oxfolder.data.module != "calendar") {
 			triggerEvent("OX_New_Error",4,_("Can not create appointment in a folder other than appointment folder"));
-		}
-		else {
+			
+		} else {
 			var wholeDay=wholeday;
 			if(!startdate) {
 				startdate=new Date();
@@ -927,8 +961,12 @@ function openAppointmentPopup(e) {
 	} else {
 		selappoint=selectedAppointment;
 	}
-	if(selappoint.recurrence_position > 0 && selappoint.recurrence_id &&
-	   selappoint.recurrence_id == selappoint.id) {
+    if (!menucheckRight("WRITE")) {
+        triggerEvent("OX_New_Error", 4,
+            _("You do not have write permission for this object."));
+    } else if(   selappoint.recurrence_position > 0 && selappoint.recurrence_id
+              && selappoint.recurrence_id == selappoint.id)
+    {
 		newConfirm(_("Edit Appointment"),_("Do you want to edit the whole series or a single series appointment? Please note when changing a serial appointment, exceptions to the series are reset."),AlertPopup.SERIESBUTTON,null,null,null,null,edit_whole_series,edit_single_series);
 	} else {
 		edit_single_appointment();
