@@ -292,6 +292,10 @@ function detailAppointmentOnload(callback)
 				$("a_d_headline").firstChild.data = sStartText + sEndText;
 			}
 			
+		},
+		function(error) {
+			triggerEvent("OX_Switch_View", configGetKey("gui.calendar.view"));
+			return true;
 		}
 	); 
 }
