@@ -26,7 +26,7 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
 		this.header = oDOMHeader;
 		this.header0;
 		this.enable_action = configGetKey("modules.calendar.module");
-		var bDisplayApps = configGetKey("modules.calendar.module");
+		var bDisplayApps = configGetKey("modules.calendar.module");		
 		if(!this.enable_action) {
 			actionFunction = function () { 
 				    triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); 
@@ -568,30 +568,30 @@ function cMiniCalendar(displayPanelContainer,container,actionFunction,
 		this.currentMonth = this.todayMonth;
 		this.currentYear = this.todayYear;
 	}
-
-	
 	this.selectedDate = (selectedDate)?selectedDate.getUTCDate():this.todayDate;
 	this.selectedMonth = (selectedDate)?selectedDate.getUTCMonth():this.todayMonth;
 	this.selectedYear = (selectedDate)?selectedDate.getUTCFullYear():this.todayYear;
-	
 	this.selectedTime = Date.UTC(this.todayYear,this.todayMonth,this.todayDate);
-	
-	
-
 	this.appointmentList = new Array();	
-	
 	this.selectedID;
-	
 	this.miniCalendarAssoc = new Object();
-	
-	this.load(this); // 
-	
+	this.load(this);
 	this.oCalendar;
 	
 	this.oComboMonth;
 	this.oComboYear;	
 	this.fnKWAction = null;
 	this.actionDBLFN = null;
+	
+	this.open_in_calendar = newnode("img", { verticalAlign:"middle" }, 
+			{ src:getFullImgSrc("img/toolbar/calnder.png"), 
+			  alt: _("Show in Calendar"), title: _("Show in Calendar")});
+	register("LanguageChanged",(function(Self) {
+		return function() {
+			Self.open_in_calendar.title = _("Show in Calendar");
+			Self.open_in_calendar.alt = _("Show in Calendar");
+		}
+	})(this));
 }	
 
 cMiniCalendar.prototype = {
@@ -885,7 +885,7 @@ cMiniCalendar.prototype = {
 		var nAllDaysCount = 0;
 		var  oTable = newnode('table',{},{className:"CalMiniMainTable1 background-color-content border-color-content-default",cellPadding: 0, cellSpacing: 0, border: 0});
 		this.table = oTable;
-		var  oTableBody = newnode('tbody');	//IE specifical
+		var oTableBody = newnode('tbody');	//IE specifical
 		//oTable.id = this.subcontainer.id + "_table";
 		var oTRHead = newnode('tr');
 		var weekDays = [
@@ -899,12 +899,7 @@ cMiniCalendar.prototype = {
         
         var _nTd = newnode('td', { height:"2em", padding:"0px" }, { className: "cursorPointer" });
         if (this.fnKWAction != null) {
-        	var open_in_calendar = newnode("img", { verticalAlign:"middle" }, { src:getFullImgSrc("img/toolbar/calnder.png")});
-        	register("LanguageChanged",function() {
-				open_in_calendar.title = _("Show in Calendar");
-			});
-			
-        	 _nTd.appendChild(open_in_calendar);        
+        	 _nTd.appendChild(Self.open_in_calendar);        
         	 _nTd.onclick = function(e) {
 	            activeDay=1;
 	            activeMonth=Self.currentMonth;
