@@ -531,66 +531,59 @@ monthView.prototype = {
 	},
 	
 	attachAppointments:function (index,	calendarObjects) {
-	/////////////////////////////////////////////////////////////////////////////////////////////////
-	//	aAppointments = this.getAppointments(currentDay.nDate,oCalendarTool.nMonth,
-	//															currentDay.nCurrMonth,aAllAppointments);
+		/////////////////////////////////////////////////////////////////////////////////////////////////
+		//	aAppointments = this.getAppointments(currentDay.nDate,oCalendarTool.nMonth,
+		//															currentDay.nCurrMonth,aAllAppointments);
 	
 		var id = calendarObjects.id;
 		var folder_id = calendarObjects.folder;
 		var selectedAppointmentWeek={id : id, folder : folder_id};
 		var divAppId = 'appInWeekView' + folder_id + "_" + id;
-		
+
 		var title = calendarObjects.title;
 		var start_date = calendarObjects.start_date;
 		var end_date = calendarObjects.end_date;	
 		var full_time = calendarObjects.full_time;
 		
 		// Setze Startzeit des Termins um , falls er vor der Anzeige beginnt
-		if (start_date < this.calendar_start.getTime()) {		
-	
-	//		fulltimeStartBeforeDiff = (this.starttime - start_date)  / 1000 / 60 / 60 / 24;
+		if (start_date < this.calendar_start.getTime()) {
 			start_date=this.calendar_start.getTime();
-	//		fulltimeStartBefore = true;
 		}
 		
 		// Setze Endzeit des Termins um , falls er nach der Anzeige endet
 		if (end_date > this.calendar_end.getTime()) {
 			end_date = this.calendar_end.getTime();		
-		}	
+		}
 	
 		var startDate = new Date(start_date);	
 		var endDate = new Date(end_date);	
+		
 		var MULTstartDate = new Date(start_date);	
 		MULTstartDate.setUTCHours(0);
+		
 		var MULTendDate = new Date(end_date);		
 		MULTendDate.setUTCHours(0)
 	
 		//Create multiday appointments here
-		if(Math.round(((MULTendDate.getTime() - MULTstartDate.getTime())  / 1000 / 60 / 60 / 24)) > 0)
-		{
-			var nDaysMultiDay = Math.round((((MULTendDate.getTime() - MULTstartDate.getTime()))  / 1000 / 60 / 60 / 24));
-	
+		var nDaysMultiDay = Math.round((((MULTendDate.getTime() - MULTstartDate.getTime()))  / 1000 / 60 / 60 / 24));
+		if (nDaysMultiDay > 0) {
 			if(endDate.getUTCHours() == 0 &&
-						endDate.getUTCMinutes() == 0 &&
-									endDate.getUTCMilliseconds() == 0)
-			{
+					endDate.getUTCMinutes() == 0 &&
+								endDate.getUTCMilliseconds() == 0) {
 				nDaysMultiDay--;
-			}			
+			}	
 			var oCurrDayIter = new Date(startDate);				
-			for(var nNumDay=0;nNumDay<=nDaysMultiDay;nNumDay++)
-			{
+			for (var nNumDay=0; nNumDay<=nDaysMultiDay; nNumDay++) {
 				//do nothing at start day - that's default case
-				if(nNumDay != 0)
-				{				
-					this.doDrawAppointment(oCurrDayIter,calendarObjects,index,true);				
-				}			
+				if (nNumDay != 0) {		
+					this.doDrawAppointment(oCurrDayIter, calendarObjects, index, nNumDay<nDaysMultiDay);				
+				}
 				oCurrDayIter.setUTCDate(oCurrDayIter.getUTCDate()+1);
-                oCurrDayIter.setTime(Math.floor(oCurrDayIter.getTime() / 864e5)
-                    * 864e5); // ms / day
+                oCurrDayIter.setTime(Math.floor(oCurrDayIter.getTime() / 864e5) * 864e5); // ms / day
 			}
-		}	
-	
-		this.doDrawAppointment(startDate,calendarObjects,index,false);
+		}
+		
+		this.doDrawAppointment(startDate, calendarObjects, index, false);
 	},
 	
 	redrawAppointments: function(workWeekHeight,weekEndHeight) {
@@ -605,7 +598,7 @@ monthView.prototype = {
 		this.redraw();
 	},
 	
-	doDrawAppointment: function(startDate,calendarObjects,index,isMultiday) {
+	doDrawAppointment: function(startDate, calendarObjects, index, isMultiday) {
 		var isMultiday = isMultiday;
 		var id = calendarObjects.id;
 		var folder_id = calendarObjects.folder;
@@ -626,62 +619,38 @@ monthView.prototype = {
 		
 		if (oViewObj.app < this.show_ww && !oViewObj.day.bWeekend || 
 		    oViewObj.app < this.show_we && oViewObj.day.bWeekend) {
-	            var sAppId = sCurrId + "_" + oViewObj.app + (full_time ? "f_app" : "_app");
-				var dAppDiv = this.getAppointmentDiv(				
-				     new CalendarWorkWeekObject(
-				             calendarObjects.id, calendarObjects.folder, calendarObjects.recurrence_position, 
-				             calendarObjects.recurrence_id, calendarObjects.created_by, calendarObjects.title,
-				             start_date, calendarObjects.end_date, calendarObjects.note,
-				             calendarObjects.recurrence_type, calendarObjects.participants, 
-				             calendarObjects.full_time, calendarObjects.shown_as, calendarObjects.color_label, 
-				             null, null, null),
-	                 sAppId, full_time, isMultiday);
-				
-				$2(sCurrId).appendChild(dAppDiv);
-				addTMPId(dAppDiv);
-				calendarObjects["index"] = index;
-				this.aAppointmentAssoc[sAppId] = calendarObjects;
-				oViewObj.app++;
-				
-			/*
-			} else if(oViewObj.fdapp == 1) {
-				var sAppId = sCurrId+'_'+oViewObj.app+'f_app';
-				calendarObjects["index"] = index;
-				this.aAppointmentAssoc[sAppId] = calendarObjects;			
-				var ShowFullTimeDiv = $2(sCurrId+'_title');
-				ShowFullTimeDiv.className = 'fullTimeAppointmentMonthTitle';
-				var FTDiv = this.getAppointmentDiv(new CalendarWorkWeekObject(calendarObjects[0],calendarObjects[1],
-									calendarObjects[2],calendarObjects[3],
-									calendarObjects[4],calendarObjects[5],null,calendarObjects[7],null,calendarObjects[9],calendarObjects,null,
-																														null,null), sAppId,true,isMultiday);
-	
-			//	addDOMEvent(FTDiv,"mouseover",viewAppointmentInfo);
-				FTDiv.className += ' wholeDayBackground border-color-image';
-				ShowFullTimeDiv.appendChild(FTDiv);
-				addTMPId(FTDiv);															
-			}
-			*/
-		} else {
-			oViewObj.app++;
+			
+	        var sAppId = sCurrId + "_" + oViewObj.app + (full_time ? "f_app" : "_app");
+			var dAppDiv = this.getAppointmentDiv(				
+			     new CalendarWorkWeekObject(
+			             calendarObjects.id, calendarObjects.folder, calendarObjects.recurrence_position, 
+			             calendarObjects.recurrence_id, calendarObjects.created_by, calendarObjects.title,
+			             start_date, calendarObjects.end_date, calendarObjects.note,
+			             calendarObjects.recurrence_type, calendarObjects.participants, 
+			             calendarObjects.full_time, calendarObjects.shown_as, calendarObjects.color_label, 
+			             calendarObjects.location, null, null),
+	             sAppId, full_time, isMultiday);
+			
+			$2(sCurrId).appendChild(dAppDiv);
+			addTMPId(dAppDiv);
+			calendarObjects["index"] = index;
+			this.aAppointmentAssoc[sAppId] = calendarObjects;
 		}
+		oViewObj.app++;
 					
 		if (oViewObj.app == (this.show_ww + 1) && !oViewObj.day.bWeekend || 
 		    oViewObj.app == (this.show_we + 1) && oViewObj.day.bWeekend ) {
 			
-			var oButtonDiv = getContentAsDiv('','expandButton','but_'+sCurrId);					
-			//var oImgButtD = newnode("img",0,{src:getFullImgSrc("img/arrows/arrow_gray_down.gif")});
-			//oButtonDiv.appendChild(oImgButtD);
+			var oButtonDiv = getContentAsDiv('','expandButton','but_'+sCurrId);
 			addDOMEvent(oButtonDiv,'click',monthAction);
 			$2(sCurrId).appendChild(oButtonDiv);
 			addTMPId(oButtonDiv)		
 			oViewObj.app++;					
 		}	
 						
-		if (oViewObj.day.bWeekend && oViewObj.app > 0) {
-			if ($2(sCurrId+'_0_app')) {
-				$2(sCurrId+'_0_app').style.height = "1.0em";
-				$2(sCurrId+'_0_app').style.lineHeight = "1.0em";		
-			}
+		if (oViewObj.day.bWeekend && oViewObj.app > 0 && $2(sCurrId+'_0_app')) {
+			$2(sCurrId+'_0_app').style.height = "1.0em";
+			$2(sCurrId+'_0_app').style.lineHeight = "1.0em";
 		}					
 	
 		var aSelected = calendarSelection.getSelected();
@@ -721,8 +690,8 @@ monthView.prototype = {
 		currYear = oCompMonth.getUTCFullYear();
 		return oCompMonth;	
 	},
-	//Initialize month view with calendar data, add Appointments
 	
+	//Initialize month view with calendar data, add Appointments
 	initMonthView: function() {	
 		    var Self = this;	
 			var aAppointments = new Array();
@@ -878,9 +847,11 @@ monthView.prototype = {
 	},
 	
 	sortAppointments: function() {	
-		this.aMonthBtAppointments.sort(function(a,b){
-			return (a.end_date == b.end_date) ? (a.start_date < b.start_date) ? -1 : 1 : (a.end_date < b.end_date) ? -1 : 1;
-		});
+		this.aMonthBtAppointments.sort(
+			function(a, b){
+				return (a.full_time || a.start_date < b.start_date ? -1 : 1); 
+			}
+		);
 		for(var i=0; i<this.aMonthBtAppointments.length;i++) {
 			this.attachAppointments(this.aMonthBtAppointments[i]["indxxx"],this.aMonthBtAppointments[i]);
 		}
@@ -979,12 +950,6 @@ monthView.prototype = {
 								removeChildNodes(currentChild.childNodes[nDivIndx]);					
 								currentChild.childNodes[nDivIndx].className = 'fullTimeAppointmentMonthTitle';
 							}
-							/*
-							if(currentChild.childNodes[nDivIndx].id.split('_')[3] == 'num')
-							{
-								currentChild.childNodes[nDivIndx].className = 'dateCalendarFontSize dateAlignMonthView';
-							}	
-							*/					
 						}
 					}
 				}
@@ -1052,7 +1017,11 @@ monthView.prototype = {
 		var textDiv = newnode("div", { overflow: "hidden" }, 
 					{ className: "showAppointmentTextMonth" + (fullday ? "Full" : "") + " dateCalendarFontSize" });
 	
-		var timeDisplayString = (!fullday ? formattedTime : "") + " " + (calendarObjects.title || "");		
+		var timeDisplayString = (!fullday && !isMultiday ? formattedTime : "") + " " + (calendarObjects.title || "");		
+		
+		if (calendarObjects.location) {
+			timeDisplayString += " - " + calendarObjects.location;
+		}
 		
 		// setting confirmation styles
 		if (calendarObjects.participants.length) {
@@ -1081,7 +1050,6 @@ monthView.prototype = {
 		
 		datDIV.appendChild(shownDiv);		
 		datDIV.appendChild(textDiv);	
-		//datDIV.appendChild(oDOMTableRASTER);
 		datDIV.id = sId;	
 	
 	 	var oInplEdit = new inplaceEdit(textDiv, calendarObjects.title, 
