@@ -41,8 +41,6 @@ var newappTimestamp;
 var messageCloseWindow = _("Do you really want to discard your changes and close the window?");
 var avaliabityInitialLoaded = false;            
 var newAppointmentFolderTree = null;
-var storageCache = corewindow.storageCache;
-var reloadAppDetailView = corewindow.reloadAppDetailView;
 var messageOnCancel = false;
 var oMainFolderTree;
 var configContainsKey = corewindow.configContainsKey;
@@ -772,8 +770,13 @@ function fillFields(){
         if (!calenObj.users) {
             calenObj.users = new Array();
         }
-        calenObj.participants.push({id: folderOwner, type:1});
-        calenObj.users.push({id: folderOwner, type:1});
+        
+        var _isPub = configGetKey("gui.calendar.autoadd_participant_public");
+        var _tmpF = oMainFolderTree.cache.find_folder(clickedItem);
+        if (_isPub == undefined || _isPub || (!_isPub && _tmpF && _tmpF.oxfolder.data.type != 2)) {
+        	calenObj.participants.push({id: folderOwner, type:1});
+        	calenObj.users.push({id: folderOwner, type:1});
+        }
 	
         var extPart = {};
         // adding mail information
@@ -817,9 +820,9 @@ function fillFields(){
 		// adding participants
 		if (oFromMail && sFromModule == "contacts") {			
 			for (var i = 0; i< oFromMail.length; i++) {				
-				if (oFromMail[i][1] == 6) {
+				if (oFromMail[i][1] == 6 || oFromMail[i][7] != undefined) {
 					// these are internal users
-					calenObj['participants'].push({id: oFromMail[i][4], type: 1});
+					calenObj['participants'].push({id: oFromMail[i][4], type: oFromMail[i][7] || 1});
 					calenObj['users'].push({id: oFromMail[i][4], type:1});
 				} else {
 					// external users
@@ -1042,26 +1045,38 @@ function setEndTimeDayView(){
 	nappointment_checkDate('end');
 }
 
-function fn_afterUpload(errorUpdate)
-{
-	if(updateReminder)
-		corewindow.updateReminders();
-	
+function fn_afterUpload(errorUpdate) {
 	window.onbeforeunload=null;
 	
-	corewindow.triggerEvent("OX_Refresh_Mini_Calendar");
-	if(corewindow && corewindow.currentpath[0] == "calendar" && corewindow.currentpath[1] == "detail")
-	{
-		reloadAppDetailView(function (){
-			if(!errorUpdate)
-				setTimeout("window.close()",0);
-			},clickedItem);							
+	if (updateReminder) {
+		corewindow.updateReminders();
 	}
-	else {
-		storageCache.update(function (){
-			if(!errorUpdate)
-				setTimeout("window.close()",0);
-		});													
+	corewindow.triggerEvent("OX_Refresh_Mini_Calendar");
+	
+	// callback to close window
+	function fn_close() {
+		if (!errorUpdate) window.setTimeout("window.close()", 0);
+	}
+	
+	// is the current view of the opener of type calendar?
+	// if not we just close this window
+	if (!corewindow || corewindow.currentpath[0] != "calendar")  {
+		fn_close();
+		
+	} else {
+		// ok, it's calendar. some of the update implementations are different
+		// and needs to be triggered manually.
+		if (corewindow.currentpath[1] == "detail") {
+			corewindow.reloadAppDetailView(fn_close, clickedItem);							
+		} else if (corewindow.currentpath.join("/") == "calendar/team/day") {
+			corewindow.ctd_startContent();
+			setTimeout(fn_close, 0);
+		} else if (corewindow.currentpath.join("/") == "calendar/team/workweek") {
+			corewindow.loadTeamWeek()
+			setTimeout(fn_close, 0);
+		} else {
+			corewindow.storageCache.update(fn_close);													
+		}
 	}
 }	
 
@@ -1151,7 +1166,7 @@ function writeNewAppointment() {
 				if(ap_object.alarm >= 0)
 					updateReminder = true;
 					
-				if(ap.newappointment_notification.checked) ap_object.notification = true;
+				ap_object.notification = ap.newappointment_notification.checked;
 				if(newAppointment.participants == undefined) {
 					//Besitzer des Folders
 					if (!folderOwner) {
@@ -1195,7 +1210,7 @@ function writeNewAppointment() {
 							fn_afterUpload();
 						}
 					} else if (cb && cb.data && cb.data.conflicts) {
-						ConflictsPopup.open(cb, cb.data.conflicts, cb_cancelCloseConflict, cb_cancelCloseConflict, cb_ignoreConflict);
+						ConflictsPopup.open(ap_object, cb.data.conflicts, cb_cancelCloseConflict, cb_cancelCloseConflict, cb_ignoreConflict);
 					}
 				});
 			} else if(ap_object.end_date < ap_object.start_date){
@@ -1304,6 +1319,8 @@ function writeNewAppointment() {
 				
 				if (ap.newappointment_notification.checked && calenObj.notification != true) {
 					ap_object.notification = true;
+				} else {
+					ap_object.notification = false;
 				}
 				
                 if (globalseries != null) {
@@ -1333,7 +1350,7 @@ function writeNewAppointment() {
 
 						}
 					} else if (cb && cb.data && cb.data.conflicts){
-						ConflictsPopup.open(cb, cb.data.conflicts, cb_cancelCloseConflict, cb_cancelCloseConflict, cb_ignoreConflict);
+						ConflictsPopup.open(ap_object, cb.data.conflicts, cb_cancelCloseConflict, cb_cancelCloseConflict, cb_ignoreConflict);
 					}
 				});
 			} else if(ap_object.end_date < ap_object.start_date){
@@ -1502,6 +1519,49 @@ function startAvailability() {
 		cn_avail_updateHeaderTime();
 		calendar_new_availability_checkFreebusy();		
 	}
+	
+	var hover=new Hover($("cnavail_freebusy_content"), OXAppointmentHover.getContent().node);	
+	hover.setSize(OXAppointmentHover.contentobject.node);
+    hover.getTarget = function (node) {
+        try {
+            while (node) {
+                if (node.ox_user != undefined && node.ox_app_id != undefined) {
+                    return node.parentNode ? node : null;
+                }
+                node = node.parentNode;
+            }
+        } catch (e) { /*see default implementation*/ }
+    };
+	hover.onShow = function (node) {
+		OXAppointmentHover.actualHover = this;
+		var obj = calendar_new_availability_objects.users[node.ox_user][node.ox_app_id];
+		
+		if (obj.id != undefined && obj.folder_id != undefined) {
+			// we have a folder and a object id so we can use the regular hover
+			OXAppointmentHover.refillContent(obj.id, obj.folder_id, obj.recurrence_position || 1);
+		} else {
+			// disable tabs we don't need
+			OXAppointmentHover.slider.getTabById("participants").show(false);
+			OXAppointmentHover.slider.getTabById("attachments").show(false);
+			OXAppointmentHover.slider.getTabById("others").show(false);
+			OXAppointmentHover.refillContentByObject(obj);
+		}
+		
+		OXAppointmentHover.accordion.removeComponent("ConfirmDialog")
+		if (OXAppointmentHover.accordion.components["ParticipantsUsers"]) {
+			OXAppointmentHover.accordion.components["ParticipantsUsers"].content.getElementsByTagName("td")[1].style.display="none";
+		}
+	}
+	hover.onHide = function (node) {
+		// re-enable tabs for later use
+		OXAppointmentHover.slider.getTabById("participants").show(true);
+		OXAppointmentHover.slider.getTabById("attachments").show(true);
+		OXAppointmentHover.slider.getTabById("others").show(true);
+	}
+	if (configGetKey("gui.effects.hover.calendar")) {
+		OXAppointmentHover.disableConfirmation = true;
+		hover.enable();		
+	}
 }
 function setScrollPoint() {
 	if(calendar_resize_first) {
@@ -2031,7 +2091,10 @@ function cnavail_drawnewLineFreeBusy(linetype,object) {
 				}
 				var newfreebusy=document.getElementById("cnavail_freebusy_template").cloneNode(false);
 				removeChildNodes(newfreebusy);
-				newfreebusy.id="Alt"+superzaehler2++;
+				newfreebusy.id = ids[zaehler7] + "-" + zaehler2 + "-" + superzaehler2++;
+				newfreebusy.ox_user = ids[zaehler7];
+				newfreebusy.ox_app_id = zaehler2;
+				
 				newfreebusy.style.left=(startpoint*15)+"px";
 				newfreebusy.style.width=((endpoint-startpoint)*15)+"px";
 				switch (data1.shown_as) {
