@@ -21,7 +21,7 @@
     getTeamMember = function(id) { return team[id]; };
     
     setTeam = function(members, silent) {
-        team = [];
+        team = {};
         addToTeam(members, silent);
     };
 
@@ -80,11 +80,10 @@
 
 var firstteam=true;
 function filldefaultteam() { 
-	if(firstteam) {
+	if (firstteam) {
 		var teams=new Array();
-		if(configContainsKey("gui.calendar.teams")) {
+		if (configContainsKey("gui.calendar.teams")) {
 			teams=configGetKey("gui.calendar.teams");
-			
 		}
         for(var i=0;i<teams.length;i++) {
 			if(teams[i].team_default) {
@@ -95,16 +94,28 @@ function filldefaultteam() {
 		firstteam=false;
 	}
 }
-register("OX_Configuration_Loaded_Complete",
-function() {
+
+register("OX_Configuration_Changed", resetCTD);
+register("OX_Configuration_Loaded_Complete", resetCTD);
+
+var ctd_reset=true;
+var ctd_interval, ctd_scroll_offset, pxPerInterval;
+function resetCTD() {
+    ctd_reset = true;
+    ctd_interval = configGetKey("gui.calendar.interval") || 30;
+    pxPerInterval = Math.max(10, ctd_interval * 2/3); // px/min
+    ctd_scroll_offset = pxPerInterval * 30 / ctd_interval; // min/h / 2
 	var mydivs=$("ctd_timeline_scroller").getElementsByTagName("div");
+    var width = pxPerInterval * 60 / ctd_interval + "px"; // min/h
 	for(var i=0;i<mydivs.length-1;i++) {
 		
 		mydivs[i].firstChild.nodeValue =
             formatDate(new Date(i * 36e5 /* ms/h */), "onlyhour");
+        mydivs[i].style.width = width;
 	}
 	ctd_scroll();
-});
+}
+
 var team_participants_selected=new Array();
 var ctd_date=new Date();
 
@@ -116,9 +127,6 @@ function ctd_createKeyfromUserObject(object) {
 	return ""+object.id+":"+object.type+"";
 }
 
-//TODO 
-/** ctd_reset = true if Configuration_Changed */
-//register("Loaded",);
 register("OX_Calendar_Teammember_Add",team_changeTeammembers);
 register("OX_Calendar_Teammember_Remove",team_removeTeammembers);
 register("OX_Selected_Member",team_storeSelectedMember);
@@ -142,6 +150,50 @@ function team_initContent() {
             }
         };
     }
+    
+    var hover=new Hover($("ctd_content"),OXAppointmentHover.getContent().node);
+	calendarhovers["teamday"]=hover;
+	
+	hover.setSize(OXAppointmentHover.contentobject.node);
+	hover.getTarget = function (node) {
+        try {
+            while (node) {
+                if (node.ox_object_id) return node.parentNode ? node : null;
+                node = node.parentNode;
+            }
+        } catch (e) { /*see default implementation*/ }
+    };
+	hover.onShow = function (node) {
+		OXAppointmentHover.actualHover = this;
+		var ref 	  = node.ox_user;
+		var folder_id = node.ox_folder_id;
+		var object_id = node.ox_object_id;
+		var rec_pos   = node.ox_rec_pos;
+		if (object_id != undefined && folder_id != undefined) {
+			// we have a folder and a object id so we can use the regular hover
+			OXAppointmentHover.refillContent(object_id, folder_id, rec_pos);
+		} else if (ref != undefined && ctd_storages[ref]) {
+			// we don't have read permission so we just show content we are allowed to
+			var obj = { };
+			for (var i in ctd_storages[ref].freebusy_response) {
+				if (object_id == ctd_storages[ref].freebusy_response[i].id) {
+					obj = clone(ctd_storages[ref].freebusy_response[i]);
+					break;
+				}
+			}
+			// disable tabs we don't need
+			OXAppointmentHover.slider.getTabById("participants").show(false);
+			OXAppointmentHover.slider.getTabById("attachments").show(false);
+			OXAppointmentHover.slider.getTabById("others").show(false);
+			OXAppointmentHover.refillContentByObject(obj);
+		}
+	}
+	hover.onHide = function (node) {
+		// re-enable tabs for later use
+		OXAppointmentHover.slider.getTabById("participants").show(true);
+		OXAppointmentHover.slider.getTabById("attachments").show(true);
+		OXAppointmentHover.slider.getTabById("others").show(true);
+	}    
 }
 function team_removeTeammembers() {
 	removeFromTeam(team_participants_selected);
@@ -160,9 +212,6 @@ function team_createParticipantsPopUp() {
 
 var template_content_oneline; 
 
-var ctd_reset=true;
-
-
 /** Execute when display **/
 function ctd_startContent() {
 	triggerEvent("Selected",0);
@@ -204,13 +253,12 @@ function ctd_changeTeammember(element) {
 	}
 	var elemid=element.id.substring(4,element.id.length);
 	var member = getTeamMember(elemid);
-    if(member) {
-		
+    if (member) {
 		triggerEvent("OX_Selected_Member",[member]);
 	}
-	for(i=0;i<team_participants_selected.length;i++) {
-		var myid="ctd_"+ctd_createKeyfromUserObject(team_participants_selected[i]);
-		if(document.getElementById(myid)) {
+	for(i=0; i<team_participants_selected.length; i++) {
+		var myid = "ctd_"+ctd_createKeyfromUserObject(team_participants_selected[i]);
+		if (document.getElementById(myid)) {
 			document.getElementById(myid).className="background-color-selection-elements font-weight-high font-color-selected";
 		}		
 	}
@@ -256,18 +304,75 @@ function ctd_reloadTeamUsers(response) {
 	var contentsbody=document.createElement("tbody");
 	
 	for (key in response) {
-		if(response[key].type<5) {
+		if (response[key].type<5) {
 			ctd_storages[key]=new Object();
 			ctd_storages[key].userobject=response[key];
 			ctd_storages[key].divs=new Array();
 			ctd_storages[key].divs[0]=ctd_fillTeammemberField(response[key]);
-			ctd_storages[key].divs[1]=template_content_oneline.cloneNode(true);
+			ctd_storages[key].divs[1]=template_content_oneline.cloneNode(true);			
+			
+			function getTarget(node) {
+				function getNode(actualnode) {
+					if (actualnode.getAttribute("ox_time")) {
+						return actualnode;
+					}
+					return;
+				}
+				while (node) {
+					var element=getNode(node);
+					if (element) {
+						return element;
+					}
+					try {
+					   node = node.parentNode;
+					} catch (e) { 
+						node = null;
+					} 
+				}
+				return;
+			}
+			
+			/*
+			 * good idea but not intuitive for the user. otherwise the 'add all users
+			 * when click on the new button in panel' makes no sense. should be reviewed.
+			 */
+			addDOMEvent(ctd_storages[key].divs[1], "click", 
+					(function(id) {
+						return function(e) {
+							// selecting member on the left side
+							ctd_changeTeammember($ALL("ctd_"+id));
+						}
+					})(key)
+			);
+			
+			
+			addDOMEvent(ctd_storages[key].divs[1], "dblclick", 
+					(function(id, response) {
+						return function(e) {
+							var node = getTarget(e.srcElement || e.target);
+							var date = new Date(Date.UTC(activeYear, activeMonth, activeDay, 0, 0, 0));
+							// setting clicked date
+							if (node) {
+								date = new Date(date.getTime() + parseInt(node.getAttribute("ox_time")));
+							}
+							// trigger new window with clicked paramter
+							calendar_createNewAppointment(
+									date,
+									activefolder,false,
+									{ "data"  : [[0, 0, response.display_name, 0, response.id, 0, 0, response.type]], 
+										  "module": "contacts" });							
+							stopEvent(e);
+						}
+					})(key, response[key])
+			);
+			
 			teamsbody.appendChild(ctd_storages[key].divs[0]);
 			contentsbody.appendChild(ctd_storages[key].divs[1]);	
 		} else {
 			delete response[key];
 		}
 	}
+	
 	teamsbody.appendChild(ctd_fillTeammemberField(null));
 	teams.appendChild(teamsbody);
 	contents.appendChild(contentsbody);
@@ -324,7 +429,7 @@ function fillFreeBusyRequest(response) {
 function ctd_showObjects() {
 	for (user in ctd_storages) {
 		var myappointments=ctd_storages[user].freebusy_response;
-		ctd_storages[user].matrix=new Array((Math.round((1000*60*60*24)/(1000*60*15))));
+		ctd_storages[user].matrix=new Array(1440 / ctd_interval); // min/day
 		for(z1=0;z1<ctd_storages[user].matrix.length;z1++)
 		{
 			ctd_storages[user].matrix[z1]=new Array();
@@ -340,19 +445,17 @@ function ctd_drawAppointments(user,appointmentfreebusy) {
 	var myobject=appointmentfreebusy;
 	if(ctd_calendar_objects[myobject.id]) {
 		myobject=ctd_calendar_objects[myobject.id];
-	}
-	else
-	{
-		myobject.start_date=new Date(myobject.start_date);
-		myobject.end_date=new Date(myobject.end_date);
+	} else {
+		//myobject.start_date=new Date(myobject.start_date);
+		//myobject.end_date=new Date(myobject.end_date);
 	}
 	ctd_drawAppointment(user,myobject);
 }
 var ctd_idcounter=0;
 function ctd_drawAppointment(user,calendarobject)
 {
-	var ctdline=10;
-	var myinterval=1000*60*15;
+    var ctdline = pxPerInterval;
+	var myinterval = 6e4 * ctd_interval; // ms/min
 	var oneday=1000*60*60*24;
 	var myintervalcounts=Math.round(oneday/myinterval);
 	
@@ -361,16 +464,14 @@ function ctd_drawAppointment(user,calendarobject)
 
 	// Startdate Correction Complete Appointment
 	// Setze Startzeit des Termins um , falls er vor meiner Anzeige beginnt
-	var sdt=calendarobject["start_date"].getTime();
+	var sdt=calendarobject["start_date"];
 	if(sdt<ctd_date.getTime()) {
-		calendarobject["start_date"]=new Date(ctd_date.getTime());
-		sdt=calendarobject["start_date"].getTime();
+		sdt=ctd_date.getTime()
 	}
 	// Setze Endzeit des Termins um , falls er nach meiner Anzeige beginnt
-	var edt=calendarobject["end_date"].getTime();
+	var edt=calendarobject["end_date"];
 	if(edt>ctd_date.getTime()+1*(oneday)) {
-		calendarobject["end_date"]=new Date(ctd_date.getTime()+(1*oneday));
-		edt=calendarobject["end_date"].getTime();
+		edt=new Date(ctd_date.getTime()+(1*oneday));
 	}
 	var sdttmp=sdt;
 	while(sdttmp<edt)
@@ -390,133 +491,148 @@ function ctd_drawAppointment(user,calendarobject)
 		var tiefe=0;  			//Place
 		var allelements=0;		//AllElements
 	
-		for (zaehler=startpoint;zaehler<endpoint;zaehler++) {
-			var maxelements = ctd_storages[user].matrix[zaehler].length;
+		for (var i = startpoint; i < endpoint; i++) {
+			var maxelements = ctd_storages[user].matrix[i].length;
 			if(allelements<maxelements) {
 				allelements=maxelements;
 			} 
-			if(ctd_storages[user].matrix[zaehler][tiefe]) {
+			if(ctd_storages[user].matrix[i][tiefe]) {
 				tiefe++;
-				zaehler=startpoint;
+				i = startpoint;
 				if(tiefe==2) {
 					showappointment=false;	
 					break;
 				}
 			}
 		}
-		if(!showappointment){
-		//	document.getElementById("cwwmoreappointments"+sdd).style.display="";
-		} else {
-			var myappointment=$("ctd_appointment_template").cloneNode(true);
-			myappointment.id=+calendarobject.folder_id +"-"+calendarobject.id+"-"+ctd_idcounter;
-			ctd_idcounter++
-			var appointmentcontainer=ctd_storages[user].divs[1].getElementsByTagName("div")[0];
+
+		var myappointment=$("ctd_appointment_template").cloneNode(true);
+		myappointment.id=+calendarobject.folder_id +"-"+calendarobject.id+"-"+ctd_idcounter;
 		
+		myappointment.ox_user   = user;
+		if (calendarobject.folder_id) {
+			myappointment.ox_folder_id = calendarobject.folder_id;
+		}
+		myappointment.ox_object_id = calendarobject.id;
+		myappointment.ox_rec_pos = ctd_idcounter;
+		myappointment.id =+ calendarobject.folder_id + "-"  +calendarobject.id + "-" + ctd_idcounter;
+		
+		ctd_idcounter++
+		var appointmentcontainer=ctd_storages[user].divs[1].getElementsByTagName("div")[0];
+	
 		//FILL APPOINTMENTS
-			var ddivs=myappointment.getElementsByTagName("div");
-			// Shown As 
-			switch (calendarobject.shown_as) {
-				case 1:
-					ddivs[0].className="appointmentRESERVED";
-					break;
-				case 2:
-					ddivs[0].className="appointmentTEMPORARY";
-					break;
-				case 3:
-					ddivs[0].className="appointmentABSENT";
-					break;
-				case 4:
-					ddivs[0].className="appointmentFREE";
-					break;
+		var ddivs=myappointment.getElementsByTagName("div");
+		// Shown As 
+		switch (calendarobject.shown_as) {
+			case 1:
+				ddivs[0].className="appointmentRESERVED";
+				break;
+			case 2:
+				ddivs[0].className="appointmentTEMPORARY";
+				break;
+			case 3:
+				ddivs[0].className="appointmentABSENT";
+				break;
+			case 4:
+				ddivs[0].className="appointmentFREE";
+				break;
+		}
+		// Title 
+		if(calendarobject.title) {
+			ddivs[1].firstChild.nodeValue=calendarobject.title;
+		}
+		else {
+			ddivs[1].firstChild.nodeValue="";
+		}
+		// Recurrence Type 
+		if(calendarobject.recurrence_type) {
+			if(calendarobject.recurrence_type!=0) {
+				ddivs[2].style.paddingLeft="7px";
+				ddivs[2].innerHTML="<img src='"+getFullImgSrc("img/calendar/calendar_series.gif")+"'></img>";
 			}
-			// Title 
-			if(calendarobject.title) {
-				ddivs[1].firstChild.nodeValue=calendarobject.title;
+		}		
+		// Tagging 
+		if(calendarobject.color_label && calendarobject.color_label!=0) {
+			ddivs[3].style.display = "block";
+			ddivs[3].style.paddingLeft="7px";
+			ddivs[3].innerHTML="<img src='"+getFullImgSrc("img/menu/tag_"+calendarobject["color_label"]+".gif")+"' alt='tag' />";
+		} else 
+			ddivs[3].style.display = "none";
+		if(calendarobject.private_flag) {
+			ddivs[4].style.display = "block";
+			ddivs[4].innerHTML="<img src='"+getFullImgSrc("img/private_flag.gif")+"' alt='private' />";
+		} else {
+			ddivs[4].style.display = "none";
+		}	
+		//New Element is Latest
+		if(allelements<tiefe+1) {
+			allelements=tiefe+1;
+		}
+		appointmentcontainer.appendChild(myappointment);
+		for(zaehler=startpoint;zaehler<endpoint;zaehler++)
+		{
+			ctd_storages[user].matrix[zaehler][tiefe]=new MatrixObject(calendarobject.folder_id,calendarobject.id,calendarobject.recurrence_id,myappointment.id);
+			for(superzaehler=allelements;superzaehler>=0;superzaehler--) {
+				//REDRAW ALL APPOINTMENTS IF EXISTS
+				if(ctd_storages[user].matrix[zaehler][superzaehler])	
+				{
+					myappointment.style.width=((endpoint-startpoint)*ctdline)-2+"px";	
+					myappointment.style.left=startpoint*ctdline+"px";
+					ctd_redrawAppointment(allelements,superzaehler,ctd_storages[user].matrix[zaehler][superzaehler].element_id);					
+				}						
 			}
-			else {
-				ddivs[1].firstChild.nodeValue="";
-			}
-			// Recurrence Type 
-			if(calendarobject.recurrence_type) {
-				if(calendarobject.recurrence_type!=0) {
-					ddivs[2].style.paddingLeft="7px";
-					ddivs[2].innerHTML="<img src='"+getFullImgSrc("img/calendar/calendar_series.gif")+"'></img>";
-				}
-			}		
-			// Tagging 
-			if(calendarobject.color_label && calendarobject.color_label!=0) {
-				ddivs[3].style.display = "block";
-				ddivs[3].style.paddingLeft="7px";
-				ddivs[3].innerHTML="<img src='"+getFullImgSrc("img/menu/tag_"+calendarobject["color_label"]+".gif")+"' alt='tag' />";
-			} else 
-				ddivs[3].style.display = "none";
-			if(calendarobject.private_flag) {
-				ddivs[4].style.display = "block";
-				ddivs[4].innerHTML="<img src='"+getFullImgSrc("img/private_flag.gif")+"' alt='private' />";
-			} else {
-				ddivs[4].style.display = "none";
-			}	
-			//New Element is Latest
-			if(allelements<tiefe+1) {
-				allelements=tiefe+1;
-			}
-			appointmentcontainer.appendChild(myappointment);
-			for(zaehler=startpoint;zaehler<endpoint;zaehler++)
-			{
-				ctd_storages[user].matrix[zaehler][tiefe]=new MatrixObject(calendarobject.folder_id,calendarobject.id,calendarobject.recurrence_id,myappointment.id);
-				for(superzaehler=allelements;superzaehler>=0;superzaehler--) {
-					//REDRAW ALL APPOINTMENTS IF EXISTS
-					if(ctd_storages[user].matrix[zaehler][superzaehler])	
-					{
-						myappointment.style.width=((endpoint-startpoint)*ctdline)-2+"px";	
-						myappointment.style.left=startpoint*ctdline+"px";
-						ctd_redrawAppointment(allelements,superzaehler,ctd_storages[user].matrix[zaehler][superzaehler].element_id);					
-					}						
-				}
-			}
-			
 		}
 		if(sdt==sdttmp) {
 			sdttmp = sdttmp - (sdttmp % oneday);
 		}
 		sdttmp = sdttmp+oneday;
 	}
+	
+	// scroll to begin of work-time
+	if ($ALL("ctd_worktime_start")) {
+		$("ctd_scroller").scrollLeft = $ALL("ctd_worktime_start").offsetLeft - ctd_scroll_offset;
+	}
 }
 function ctd_redrawAppointment(elementlength,position,elementid) {
 	var d=document.getElementById(elementid);
-	d.style.height=(Math.round(100/elementlength)-4)+"%";
-	d.style.top=(Math.round(100/elementlength)*position)+"%";
+	if (d) {
+		d.style.height=(Math.round(100/elementlength)-4)+"%";
+		d.style.top=(Math.round(100/elementlength)*position)+"%";
+	}
 }	
 function ctd_createTemplates() {
-	var startworktime  = 1000*60*60*8;
-	var endworktime  = 1000*60*60*18;
+	var startworktime  = 1000*60*60 * configGetKey("gui.calendar.starttime");
+	var endworktime  = 1000*60*60 * configGetKey("gui.calendar.endtime");
 	ctd_createCalendarContent(startworktime,endworktime);
 }
 function ctd_createCalendarContent(startworktime,endworktime) {
-	var templateofftime =$("ctd_template_contentofftime");
-	var templateworktime=$("ctd_template_contentworktime");
-	template_content_oneline=document.createElement("tr");
-	for (var i=0;i<24;i++) {
-		if(((i*1000*60*60)<startworktime) || ((i*1000*60*60)>=endworktime)) {
-			var mytemp=templateofftime.cloneNode(true);
-			mytemp.id="";
-			if(i==0) {
-				mytemp.getElementsByTagName("div")[0].style.position="relative";
-			}
-			template_content_oneline.appendChild(mytemp);
-		} else {
-			var mytemp=templateworktime.cloneNode(true);
-			mytemp.id="";
-			if(i==0) {
-				mytemp.getElementsByTagName("div")[0].style.position="relative";
-			}
-			template_content_oneline.appendChild(mytemp);
-		}
-	}
+    // usage: templates[worktime][fullhour]
+    var templates = { "false": { "false": $("ctd_template_contentofftime2"),
+                                  "true": $("ctd_template_contentofftime") },
+                       "true": { "false": $("ctd_template_contentworktime2"),
+                                  "true": $("ctd_template_contentworktime") } };
+    template_content_oneline=document.createElement("tr");
+    var interval = ctd_interval * 6e4; // ms/min
+    var worktime = false;
+    for (var i = 0; i < 864e5; i += interval) { // ms/day
+        var mytemp = templates[i >= startworktime && i < endworktime]
+                              [i % 36e5 == 0].cloneNode(true); // ms/h
+    	mytemp.id="";
+    	if (!worktime && i >= startworktime) {
+    		mytemp.id="ctd_worktime_start";
+    		worktime = true;
+    	}
+    	mytemp.setAttribute("ox_time", String(i));
+    	
+        var style = mytemp.getElementsByTagName("div")[0].style;
+        style.width = pxPerInterval - 1 + "px";
+        if (!i) style.position="relative";
+        template_content_oneline.appendChild(mytemp);
+    }
 }
 function ctd_scroll() {
 	var scroll1=$("ctd_scroller");
-	$("ctd_participants_scroller").scrollTop= (scroll1.scrollTop) ;
-	$("ctd_timeline_scroller").scrollLeft=(scroll1.scrollLeft) + 20;
+	$("ctd_participants_scroller").scrollTop = (scroll1.scrollTop) ;
+	$("ctd_timeline_scroller").scrollLeft = (scroll1.scrollLeft) + ctd_scroll_offset;
 }
 fileloaded();
\ No newline at end of file
