@@ -53,10 +53,47 @@ function loadTeamWeek()
     resizeEvents.register("Resized",resizeTeamWeekHeader);
     
     var team = getTeamList();
-    if(team)
-    {
+    if (team) {
         oTeamWeek.updateMemberList (team);
     }
+    
+    var hover=new Hover($("teamWeekBody"),OXAppointmentHover.getContent().node);
+	calendarhovers["teamworkweek"]=hover;
+	
+	hover.setSize(OXAppointmentHover.contentobject.node);
+	hover.getTarget = function (node) {
+        try {
+            while (node) {
+                if (node.id && node.id.indexOf("app_d_team_week_row") != -1) {
+    				return node.parentNode ? node : null;
+                }
+                node = node.parentNode;
+            }
+        } catch (e) { /*see default implementation*/ }
+    };
+	hover.onShow = function (node) {
+		OXAppointmentHover.actualHover = this;
+		var obj = oTeamWeek.app_assoc[node.id];
+		if (obj == undefined) return false;
+		
+		if (obj.id != undefined && obj.folder_id != undefined) {
+			// we have a folder and a object id so we can use the regular hover
+			OXAppointmentHover.refillContent(obj.id, obj.folder_id, obj.recurrence_position || 1);
+		} else {
+			// we don't have read permission so we just show content we are allowed to			
+			// disable tabs we don't need
+			OXAppointmentHover.slider.getTabById("participants").show(false);
+			OXAppointmentHover.slider.getTabById("attachments").show(false);
+			OXAppointmentHover.slider.getTabById("others").show(false);
+			OXAppointmentHover.refillContentByObject(obj);
+		}
+	}
+	hover.onHide = function (node) {
+		// re-enable tabs for later use
+		OXAppointmentHover.slider.getTabById("participants").show(true);
+		OXAppointmentHover.slider.getTabById("attachments").show(true);
+		OXAppointmentHover.slider.getTabById("others").show(true);
+	}
 }
 
 function resizeTeamWeekHeader()
@@ -72,6 +109,45 @@ function clickMemberTeamWeek(obj)
     oTeamWeek.selectMember(sTRId);
     document.getElementById('u_team_week' + '_' + obj.id.split('_')[3]).className += ' background-color-selection-elements font-weight-high font-color-selected';
 }
+function dblClickMemberTeamWeek(e) {
+    if (!oTeamWeek || !oTeamWeek.selected_member.length) return; 
+    function getTarget(node) {
+		function getNode(actualnode) {
+			if (actualnode.getAttribute("ox_time")) {
+				return actualnode;
+			}
+			return;
+		}
+		while (node) {
+			var element=getNode(node);
+			if (element) {
+				return element;
+			}
+			try {
+			   node = node.parentNode;
+			} catch (e) { 
+				node = null;
+			} 
+		}
+		return;
+	}
+    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay, 0, 0, 0));
+	// setting clicked date
+    var node = getTarget(e.srcElement || e.target);
+	if (node && node.getAttribute("ox_time")) {
+		date = new Date(oTeamWeek.monday.getTime()
+				+ (864e5 * parseInt(node.getAttribute("ox_time"))));
+		date.setUTCHours(new Date().getHours())
+		date.setUTCMinutes(0);
+	}
+    // trigger new window with clicked paramter
+	calendar_createNewAppointment(
+			date,
+			activefolder,false,
+			{ "data"  : [[0, 0, oTeamWeek.selected_member[0].display_name, 0, oTeamWeek.selected_member[0].id, 0, 0, oTeamWeek.selected_member[0].type]], 
+				  "module": "contacts" });
+	stopEvent(e);
+}
 
 /////////////////////////////////////////////////////////////////////////
 function teamWeek()
@@ -176,7 +252,7 @@ clearAppView:function ()
             {
                 oParentDiv.removeChild(oParentDiv.firstChild);
             }
-            oParentDiv.innerHTML = '&#xa0;';
+            oParentDiv.innerHTML = '&#xa0;';            
         }
     }
     this.app_collector = new Object();  
@@ -188,10 +264,13 @@ drawAppointments:function (oAppointments,nRowId)
     function duplicate_app(app) {
         var copyApp = new Object();
         copyApp["id"] = app.id;
+        copyApp["folder_id"] = app.folder_id;
         copyApp["start_date"] = app.start_date;
         copyApp["end_date"] = app.end_date;
         copyApp["shown_as"] = app.shown_as;                                                         
         copyApp["full_time"] = app.full_time;
+        copyApp["created_by"] = app.created_by;
+        copyApp["full_time"] = app.full_time;
         copyApp["title"] = app.title
         return copyApp;
     }
@@ -554,17 +633,18 @@ addMember: function (oMember)
 {
     var oTeml = this.template.cloneNode(true);
     oTeml.id += '_' + this.membercount; 
-    for(var indx=0;indx<oTeml.childNodes.length;indx++)
-    {
-        for(var indx2 = 0;indx2<oTeml.childNodes[indx].childNodes.length;indx2++)
-        {
-            if(oTeml.childNodes[indx].childNodes[indx2].id == 'u_team_week')
-            {
-                var oDOMText = document.createTextNode(oMember.display_name);
-                oTeml.childNodes[indx].childNodes[indx2].appendChild(oDOMText);
-            }
-            oTeml.childNodes[indx].childNodes[indx2].id += '_' + this.membercount;
-        }
+    var arr = oTeml.getElementsByTagName("div");
+    for (var i in arr) {    	
+    	var div = arr[i];
+    	if (div.id == "u_team_week") {
+            div.appendChild(document.createTextNode(oMember.display_name));
+    	} else if (div.setAttribute) {
+    		div.setAttribute("ox_time", String(i-1));
+    		addDOMEvent(div, "dblclick", dblClickMemberTeamWeek);
+    	} 
+    	if (div.id) {
+    		div.id += "_" + this.membercount;
+    	}
     }
     this.container.appendChild(oTeml);
     if(!this.membercount)
