@@ -63,25 +63,13 @@ WeekCalendarTool.prototype = {
 			
 			hover.setSize(OXAppointmentHover.contentobject.node);
 			hover.getTarget = function (node) {
-				function getNode(actualnode) {
-					if(actualnode.oxcalobj) {
-						return actualnode;
-					}
-					return;
-				}
-				while (node) {
-					var element=getNode(node);
-					if(element) {
-						return element;
-					}
-					try {
-					   node = node.parentNode;
-					} catch (e) { 
-						node = null;
-					} 
-				}
-				return;
-			}
+                try {
+                    while (node) {
+                        if (node.oxcalobj) return node.parentNode ? node : null;
+                        node = node.parentNode;
+                    }
+                } catch (e) { /*see default implementation*/ }
+            };
 			hover.onShow = function (node) {
 				OXAppointmentHover.actualHover=this;
 				var splitid=node.oxcalobj.split("-");
@@ -443,14 +431,10 @@ WeekCalendarTool.prototype = {
 	getAppointmentDiv:function (object) {
 		var appointmentDate = new Date(object.start_date);
 		var appointmentDateEnd = new Date(object.end_date);
-		var formatForStart = (appointmentDate.getUTCMinutes()<10)? "0":"";
-		var formatForEnd = (appointmentDateEnd.getUTCMinutes()<10)? "0":"";
 		if(!object.title) {
 			object.title="";
 		}
-		var textToView = appointmentDate.getUTCHours() + ":" + formatForStart + appointmentDate.getUTCMinutes() + " - ";
-		textToView += appointmentDateEnd.getUTCHours() + ":" + formatForEnd + appointmentDateEnd.getUTCMinutes() + " ";
-		textToView += object.title;		
+		var textToView = formatDate(appointmentDate, "time") + " - " + formatDate(appointmentDateEnd, "time") + "  " + object.title;
 		var shownDiv = getShownDiv(object.shown_as);
 		
 		var divIconParticipant = newnode("div", {},{ className: "showAppointmentSeqWeek"});
@@ -524,7 +508,7 @@ WeekCalendarTool.prototype = {
 		
 		return datDIV;						
 	},
-	generateCalendarObjects: function(index, object) {
+	generateCalendarObjects: function(index, object) {		
 		this.index = index;
 		this.object = object;
 		var id = this.object[0];
@@ -540,6 +524,11 @@ WeekCalendarTool.prototype = {
 			recurrence_id:nRecId, created_by:created_by };
 		var divAppId = 'appInWeekView' + folder_id + "_" + id+"_"+nRecPosition;
 		
+		// additional clean-up? hack to fix bug #11406
+		if ($2(divAppId) && $2(divAppId).parentNode) {
+			$2(divAppId).parentNode.removeChild($2(divAppId));
+		}
+		
 		var title = this.object[3];
 		var start_date = this.object[4];
 		var end_date = this.object[5];
@@ -562,18 +551,15 @@ WeekCalendarTool.prototype = {
 		var full_time = this.object[9];
 		var shown_as = this.object[10];
 		var color_label = this.object[11];
+		var location = this.object[12];
 		var private_flag = this.object[13];
 		var appointmentDate = new Date(start_date);
-		var appointmentDateEnd = new Date(end_date);
-		var formatForStart = (appointmentDate.getUTCMinutes()<10)? "0":"";
-		var formatForEnd = (appointmentDateEnd.getUTCMinutes()<10)? "0":"";
-		var timeWeekpart1 = appointmentDate.getUTCHours() + ":" + formatForStart + appointmentDate.getUTCMinutes();
-		var timeWeekpart2 = appointmentDateEnd.getUTCHours() + ":" + formatForEnd + appointmentDateEnd.getUTCMinutes();
-		
-		var textToView = timeWeekpart1 + " - " + timeWeekpart2 + " ";
-		if(!title) title="";
-		textToView += title;
+		var appointmentDateEnd = new Date(end_date);''	
+		var timeWeekpart1 = formatDate(appointmentDate, "time");
+		var timeWeekpart2 = formatDate(appointmentDateEnd, "time");
 		
+		if (!title) title="";
+		var textToView =  timeWeekpart1 + " - " + timeWeekpart2 + "  " + title;
 		var divId = "weekDayContent" + appointmentDate.getUTCDay();
 		
 		this.aAppointmentAssoc[divAppId] = this.object;
@@ -631,9 +617,11 @@ WeekCalendarTool.prototype = {
 		
 		var titlesMultidays = [];
 		if (days > 1) {
-			textToView = titlesMultidays[0] = timeWeekpart1 + " - 24:00 " + title;
-			titlesMultidays[1] = "0:00 - 24:00 " + title;
-			titlesMultidays[2] = "0:00 - " + timeWeekpart2 + " " + title;
+			var timeA = formatDate(new Date(Date.UTC(1970,1,1,0,0,0)), "time");
+			var timeB = formatDate(new Date(Date.UTC(1970,1,1,23,59,59)), "time");
+			textToView = titlesMultidays[0] = timeWeekpart1 + " - " + timeB + "  " + title;
+			titlesMultidays[1] = timeA + " - " + timeB + "  " + title;
+			titlesMultidays[2] = timeA + " - " + timeWeekpart2 + "  " + title;
 		}
 
 		var Self = this;
@@ -697,6 +685,10 @@ WeekCalendarTool.prototype = {
 			var textDiv = newnode('div');
 			textDiv.className = "showAppointmentTextWeek";
 			
+			if (location) {
+				textToView += " - " + location;
+			}
+			
 			// setting confirmation styles
 			if (participants.length) {
 				for (var i in participants) {
@@ -875,7 +867,13 @@ WeekCalendarTool.prototype = {
 			ftDiv.oxcalobj=""+folder_id + "-" + id + "-" + nRecPosition;
 			ftDiv.appendChild(shownDiv);
 			addTMPId(ftDiv);
-			if(!title) { title=""; }
+			if (!title) { 
+				title = ""; 
+			}
+			if (location) {
+				title += " - " + location;
+			}
+			
 			var fullTextDiv = newnode("div", {flt:"left", width: "80%"}, null);
 			
 			// setting confirmation styles
