@@ -334,11 +334,13 @@ function updateHeaderWW(oDateLoc)
 {
 	var oHeader = $("wwViewHeader");
 	var oCalendarTool = new calendarTool(activeMonth,activeYear);
+	var oMonday = new Date(getDayInSameWeek(new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)), weekStart) * 864e5 + ((7-weekStart) * 864e5));
+	
 	currentKW = oCalendarTool.getKW(activeYear,activeMonth,activeDay);
 	if(currentpath2.join("/") == "calendar/calendar/workweek") {
 		$("wwViewHeader").parentNode.parentNode.parentNode.parentNode.parentNode.style.width="200px";
 		oHeader.style.width="160px";
-		oHeader.firstChild.nodeValue = _("CW") + " " + currentKW + " " + activeYear;		
+		oHeader.firstChild.nodeValue = _("CW") + " " + currentKW + " " + oMonday.getUTCFullYear();		
 	} else if (currentpath2.join("/") == "calendar/calendar/day"){
 		$("wwViewHeader").parentNode.parentNode.parentNode.parentNode.parentNode.style.width="200px";
 		oHeader.style.width="160px";
@@ -625,7 +627,7 @@ function cwwdrawAppointment(calendarobject) {
 					};	
 					var divs = myappointment.getElementsByTagName("div");			
 					
-					var oInplEdit  = new inplaceEdit(divs[2], calendarobject.title, function (sStr,oObj) {
+					var oInplEdit  = new inplaceEdit(divs[2], calendarobject.title, function (sStr, oObj) {
 						editAppointment(paramObj,{title:sStr});
 					});
 					oInplEdit.input_fontcolor = "#FFFFFF";
@@ -653,7 +655,7 @@ function cwwdrawAppointment(calendarobject) {
 					});
                     var tds = myappointment.getElementsByTagName("td");
                     var title = tds[1].getElementsByTagName("span")[0];
-					addDOMEvent(title, "click", myfunc1(oInplEdit));		
+					addDOMEvent(tds[1], "click", myfunc1(oInplEdit));		
 					addDOMEvent(myappointment, "click", function(e) {
 							var SelObj = calendarSelection.getID();
 							if (SelObj && SelObj.id == paramObj.id &&
@@ -699,9 +701,9 @@ function cwwdrawAppointment(calendarobject) {
 							break;
 					}
 					
-					if (!calendarobject.title) { 
-						calendarobject.title="";
-					}
+                    title.firstChild.data = calendarobject.location ?
+                        calendarobject.title + " - " + calendarobject.location :
+                        calendarobject.title || "";
 					
 					// setting confirmation styles
 					if (calendarobject.participants.length) {
@@ -726,8 +728,6 @@ function cwwdrawAppointment(calendarobject) {
 						}
 					}
 					
-					title.firstChild.nodeValue = calendarobject.title;
-					
 					appointmentcontainer.appendChild(myappointment);
 				}
 			}
@@ -747,12 +747,14 @@ function cwwdrawAppointment(calendarobject) {
 				showappointment=true;
 				var sdd        = (new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
 				var longstart  = (sdttmp % oneday);
+                if (longstart < 0) longstart += oneday;
 				var startpoint = Math.floor((longstart/globalinterval)+0.0000001);
 				var edttmp     = edt;
 				var longend    = (edt % oneday);
+                if (longend < 0) longend += oneday;
 				var endpoint   =   Math.ceil((longend/globalinterval)-0.0000001);
 				// An diesem Tag nicht zu Ende
-				if(sdttmp - (sdttmp % oneday) + oneday <= edt) {
+				if(Math.floor(sdttmp / oneday + 1) * oneday <= edt) {
 					endpoint   = globalintervalcounts;							
 				}
 				if(startpoint  ==  endpoint) {
@@ -817,7 +819,7 @@ function cwwdrawAppointment(calendarobject) {
 					};
                     var tds = myappointment.getElementsByTagName("td");
                     var title = tds[2].getElementsByTagName("span")[0];
-					addDOMEvent(title, "click", myfunc1(oInplEdit));		
+					addDOMEvent(tds[2], "click", myfunc1(oInplEdit));		
 					addDOMEvent(myappointment, "click", function(e) {
 							var SelObj = calendarSelection.getID();
 							if(SelObj && SelObj.id == paramObj.id &&
@@ -900,9 +902,9 @@ function cwwdrawAppointment(calendarobject) {
 								break;
 						}
 						/** Title & Time **/
-						if (!calendarobject.title) { 
-							calendarobject.title=""; 
-						}
+                        title.firstChild.data = calendarobject.location ?
+                            calendarobject.title + " - " + calendarobject.location :
+                            calendarobject.title || "";
 						
 						// setting confirmation styles
 						if (calendarobject.participants.length) {
@@ -926,9 +928,7 @@ function cwwdrawAppointment(calendarobject) {
 								}
 							}
 						}
-						
-						title.firstChild.data = calendarobject.title;
-	
+												
 						/** Recurrence Type **/
 						if(calendarobject.recurrence_type && calendarobject.recurrence_type!=0)
 							tds[3].getElementsByTagName("img")[0].style.display = "inline";
@@ -977,7 +977,7 @@ function cwwdrawAppointment(calendarobject) {
 				}
 			}
 			if(sdt==sdttmp) {
-				sdttmp = sdttmp - (sdttmp % oneday);
+				sdttmp = Math.floor(sdttmp / oneday) * oneday;
 			}
 			sdttmp = sdttmp+oneday;
 		}
@@ -1160,23 +1160,13 @@ function createCalendarContentFullTime() {
 	calendarhovers["daywwcustom"]=new Hover(secondtr,OXAppointmentHover.getContent().node);
 	calendarhovers["daywwcustom"].setSize(OXAppointmentHover.contentobject.node);
 	calendarhovers["daywwcustom"].getTarget = function (node) {
-		
-		function getNode(actualnode) {
-			if(actualnode.oxcalobj) {
-				return actualnode;
-			}
-			return;
-		}
-		while (node) {
-			var element=getNode(node);
-			if(element) {
-				return element;
-			}
-			node = node.parentNode;
-		}
-		return;
-		
-	}
+        try {
+            while (node) {
+                if (node.oxcalobj) return node.parentNode ? node : null;
+                node = node.parentNode;
+            }
+        } catch (e) { /*see default implementation*/ }
+    };
 	calendarhovers["daywwcustom"].onShow = function (node) {
 		OXAppointmentHover.actualHover=this;
 		var splitid=node.oxcalobj.split("-");
@@ -1313,20 +1303,12 @@ function createCalendarContentWW(interval,startworktime,endworktime){
 	calendarhovers["daywwcustom2"]=new Hover(mytable,OXAppointmentHover.getContent().node);
 	calendarhovers["daywwcustom2"].setSize(OXAppointmentHover.contentobject.node);
 	calendarhovers["daywwcustom2"].getTarget = function (node) {
-		function getNode(actualnode) {
-			if(actualnode.oxcalobj) {
-				return actualnode;
-			}
-			return;
-		}
-		while (node) {
-			var element=getNode(node);
-			if(element) {
-				return element;
-			}
-			node = node.parentNode;
-		}
-		return;
+		try {
+            while (node) {
+                if (node.oxcalobj) return node.parentNode ? node : 0;
+                node = node.parentNode;
+            }
+        } catch (e) { /*see default implementation*/ }
 	}
 	calendarhovers["daywwcustom2"].onShow = function (node) {
 		OXAppointmentHover.actualHover=this;
@@ -1616,7 +1598,7 @@ function createDDPreviewDivsWholeDay(starttime,endtime) {
 		appointmentcontainer.appendChild(myappointment);
 		zaehler++;
 		if(sdt==sdttmp) {
-			sdttmp = sdttmp - (sdttmp % oneday);
+			sdttmp = Math.floor(sdttmp / oneday) * oneday;
 		}
 		sdttmp = sdttmp+oneday;
 	}
@@ -1639,12 +1621,14 @@ function createDDPreviewDivs(starttime,endtime) {
 	{
 		var sdd        = (new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
 		var longstart  = (sdttmp % oneday);
+        if (longstart < 0) longstart += oneday;
 		var startpoint = Math.floor((longstart/globalinterval)+0.0000001);
 		var edttmp     = edt;
 		var longend    = (edt % oneday);
+        if (longend < 0) longend += oneday;
 		var endpoint   =   Math.ceil((longend/globalinterval)-0.0000001);
 		// An diesem Tag nicht zu Ende
-		if(sdttmp - (sdttmp % oneday) + oneday <= edt) {
+		if(Math.floor(sdttmp / oneday + 1) * oneday <= edt) {
 			endpoint   = globalintervalcounts;							
 		}
 		if(startpoint  ==  endpoint) {
@@ -1661,7 +1645,7 @@ function createDDPreviewDivs(starttime,endtime) {
 		var appointmentcontainer=cwwdays[sdd].node;
 		appointmentcontainer.appendChild(myappointment);
 		if(sdt==sdttmp) {
-			sdttmp = sdttmp - (sdttmp % oneday);
+			sdttmp = Math.floor(sdttmp / oneday) * oneday;
 		}
 		sdttmp = sdttmp+oneday;
 	}
@@ -1778,12 +1762,14 @@ function createPreviewNewAppointmentWW(object) {
 	{
 		var sdd        = (new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
 		var longstart  = (sdttmp % oneday);
+        if (longstart < 0) longstart += oneday;
 		var startpoint = Math.floor((longstart/globalinterval)+0.0000001);
 		var edttmp     = edt;
 		var longend    = (edt % oneday);
+        if (longend < 0) longend += oneday;
 		var endpoint   =   Math.ceil((longend/globalinterval)-0.0000001);
 		// An diesem Tag nicht zu Ende
-		if(sdttmp - (sdttmp % oneday) + oneday <= edt) {
+		if(Math.floor(sdttmp / oneday + 1) * oneday <= edt) {
 			endpoint   = globalintervalcounts;							
 		}
 		if(startpoint  ==  endpoint) {
@@ -1807,7 +1793,7 @@ function createPreviewNewAppointmentWW(object) {
 		appointmentcontainer.appendChild(myappointment);					
 		
 		if(sdt==sdttmp) {
-			sdttmp = sdttmp - (sdttmp % oneday);
+			sdttmp = Math.floor(sdttmp / oneday) * oneday;
 		}
 		sdttmp = sdttmp+oneday;
 		zaehler3++;
@@ -1845,7 +1831,8 @@ function editAppointment(object,changes, fn_opt) {
 						} 		
 					});
 				}
-				ConflictsPopup.open(changes,cb.data.conflicts,null,null,cbignore);
+				ConflictsPopup.open(object, cb.data.conflicts, null, null,
+                                    cbignore);
 				
 			} else {
 				storageCache.update(triggerEvent("OX_Refresh_Mini_Calendar"));
