@@ -33,7 +33,11 @@ var ox = {
          * Displays an error message to the user.
          * @param {I18nString} text The error message to display.
          */
-        error: function(text) { triggerEvent("OX_New_Error", 4, text()); },
+        error: function(text) {
+            setTimeout(function() {
+                triggerEvent("OX_New_Error", 4, text());
+            }, 0);
+        },
 
         /**
          * Displays an information message to the user.
