@@ -38,11 +38,31 @@ function setFlagInContactView(tag){
 }
 
 registerView("contacts",
-	null,
 	function() {
-		register("OX_Add_Flag", setFlagInContactView);		
+        $("menu_search_context").style.display = "";        
+    },
+	function() {
+		register("OX_Add_Flag", setFlagInContactView);
+        globalSearchMenu.setFields(
+            ["first_name", "last_name", "display_name", "email1", "email2",
+                "email3", "categories"],
+            ["First name"/*i18n*/, "Last name"/*i18n*/, "Display name"/*i18n*/,
+                "E-Mail (business)"/*i18n*/, "E-Mail (private)"/*i18n*/,
+                "E-Mail (other)"/*i18n*/, "Tags"/*i18n*/],
+            configGetKey("modules.contacts.gui.searchFields") ||
+                { first_name: true, last_name: true, display_name: true,
+                  email1: true, email2: true, email3: true, categories: true });
+        globalSearchMenu.onChange = function() {
+            if (config.modules.contacts.gui === "null")
+                delete config.modules.contacts.gui;
+            configSetKey("modules.contacts.gui.searchFields", this.checked);
+            ox.JSON.put(AjaxRoot + "/config/modules/contacts/gui?session=" +
+                        session, configGetKey("modules.contacts.gui"),
+                        emptyFunction);
+        };
 	},
 	function() {
+        globalSearchMenu.setFields();
 		if(tmpDetailRequest) {
             OXCache.unregister(tmpDetailRequest.uniqueName);
             tmpDetailRequest=null;
@@ -52,6 +72,7 @@ registerView("contacts",
 	},
 	function() {
 		menuclearSearch();
+        $("menu_search_context").style.display = "none";        
 	},
 	null
 );
@@ -110,21 +131,13 @@ registerView("contacts/cards",
 		}
 		
 		objContactFunctions.refHover.getTarget = function (node) {
-					function getNode(actualnode) {
-						if(actualnode.oxcontactobj) {
-							return actualnode;
-						}
-						return;
-					}
-					while (node) {
-						var element=getNode(node);
-						if(element) {
-							return element;
-						}
-						node = node.parentNode;
-					}
-					return;
-				}
+            try {
+                while (node) {
+                    if (node.oxcontactobj) return node.parentNode ? node : null;
+                    node = node.parentNode;
+                }
+            } catch (e) { /*see default implementation*/ }
+        };
 		objContactFunctions.refHover.onShow = function (node) {
 			OXContactHover.hover=this; 
 			OXContactHover.accordion.setHover(this);
@@ -361,13 +374,9 @@ ContactFunctions.prototype = {
                 search["startletter"]=true;
                 search["last_name"]=myPattern;
             } else {
-                search["display_name"]=pattern;
-                search["last_name"]=pattern;
-                search["first_name"]=pattern;
-                search["email1"]=pattern;
-                search["email2"]=pattern;
-                search["email3"]=pattern;
-                search["categories"] = pattern;
+                for (var i in globalSearchMenu.checked) {
+                    if (globalSearchMenu.checked[i]) search[i] = pattern;
+                }
                 search.operator = "or";
             }
         }
@@ -377,7 +386,7 @@ ContactFunctions.prototype = {
 			var collection={}
 			collection.criteria = criteria;
 			collection.search = search;
-			collection.columns = [];
+			collection.columns = ["mark_as_distributionlist"];
 			if(contactsCardsRequest2) {
                 OXCache.unregister(contactsCardsRequest2.uniqueName);
                 contactsCardsRequest2=null;
@@ -403,7 +412,8 @@ ContactFunctions.prototype = {
                 scrollerCbar.scrollLeft = ($("contactCardTable").clientWidth/4) * Math.floor(contactGrid.focus/cardsPerRowToView);
             } else { scrollerCbar.scrollLeft = 0; }
             scrollCardView();
-            triggerEvent("Selected", contactsSelection2.getSelected());
+            // moved triggerEvent("Selected", contactsSelection2.getSelected());
+            // from here to end of scrollCardView()
         }
 	},
 	renderWidthScrollbarDiv : function() {
@@ -991,7 +1001,8 @@ function scrollCardView(e)
         if (objContactCardFunctions) {
         	objContactCardFunctions.updateCardStyle();
         }    
-        
+        // now fire event
+        triggerEvent("Selected", contactsSelection2.getSelected());
     });
 	return;
 }
@@ -1318,30 +1329,34 @@ function wheelTableCard(e)
 /********************************** Edit Cards *****************************************************************/
 
 function setStatusDLSelection() {
+
 	isDistributionListSelected = 0;
     if (contactsSelection2 && contactsSelection2.getSelected().length == 1) {
         contactDetailId = contactsSelection2.getSelected()[0]["id"];
         if (OXCache.cachedObjects.get(contactsSelection2.getSelected()[0])["mark_as_distributionlist"]) {
-           isDistributionListSelected = 1
+           isDistributionListSelected = 1;
         }
     }
 }
 
-function editContact()
-{
-	if(menucheckRight("WRITE")) {	
-		if(typeof contactDetailId == 'object')
-		{
+function editContact() {
+	
+	// can write?
+	if(menucheckRight("WRITE")) {		
+		// have contact?
+		if(typeof contactDetailId == 'object') {
 			contactDetailId = contactDetailId.id;
 		}	
-		
+		// contact or distribution list?
 		if(isDistributionListSelected == 1) {
+			// edit as distribution list
 			openContactPopup("modul=edit&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newDistributionList.html', {id:contactDetailId, folder: activefolder});
 		} else {
+			// edit as contact
 			openContactPopup("modul=edit&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newContact.html', {id:contactDetailId, folder: activefolder});
 		}
 	} else {
-		/* "no rights"  */
+		// no write permission
 		triggerEvent("OX_New_Error", 4, _("You do not have write permission for this object."));
 	}
 }
@@ -1351,14 +1366,16 @@ function editContact()
 
 function duplicateContact()
 {
-	if(typeof contactDetailId == 'object')
-	{
+	if(typeof contactDetailId == 'object') {
 		contactDetailId = contactDetailId.id;
-	}		
+	}
 	
+	// contact or distribution list?
 	if(isDistributionListSelected == 1) {
+		// open as distribution list
 		openContactPopup("modul=duplicate&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newDistributionList.html');
 	} else {
+		// open as contract
 		openContactPopup("modul=duplicate&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newContact.html');
 	}
 }
@@ -1462,7 +1479,7 @@ function showContactDetail(cb_function) {
 		objContactCardFunctions.currentDatailContactData = daten;
 	   //TODO
 		//lastUpdateOfContactsTimestamp = daten.last_modified;
-	   $('headDisplayname').firstChild.nodeValue = daten["display_name"] || ""; 
+	   $('headDisplayname').firstChild.nodeValue = daten["display_name"] || daten["company"] || _("Detail"); 
 	   $('contact_d_count_attachment').firstChild.nodeValue = daten["number_of_attachments"] || "0";  
 		$("tagImgContactDetail").src = getFullImgSrc("img/menu/tag_"+(daten["color_label"] || 0) + ".gif"); 
 	   $("privateflagImgContactDetail").src = getFullImgSrc("img/" + (daten.private_flag ? "private_flag" : "dummy") + ".gif"); 
@@ -1532,20 +1549,27 @@ function showContactDetail(cb_function) {
                         $(idfield).appendChild(newnode("br"));
                     }
                     nText = null;
-			    } else if (idfield == "contains_image1" && daten[idfield] && daten[idfield] > 0 && daten.image1_url) {
-			        $('imageContactDetailTd').className = "";
-			        if($('imageContactDetailTd').firstChild)
-			            $('imageContactDetailTd').removeChild($('imageContactDetailTd').firstChild);
-			        $('imageContactDetailTd').appendChild(document.createElement("img"));
-			        $('imageContactDetailTd').firstChild.src = daten.image1_url;
-			    
-			    } else if (idfield == "contains_image1" && daten[idfield] && daten[idfield] < 1 || !daten["contains_image1"]) {
-			        $('imageContactDetailTd').className = "contactDummyImage border-color-default";
-			        $('imageContactDetailTd').firstChild.src=getFullImgSrc('img/contacts/dummypicture.gif');
-			        $('imageContactDetailTd').firstChild.className="border-color-content-default";
-			    }                                                   
-			}
-			
+			    }
+            }
+            // contact picture?
+            if ( daten.contains_image1 > 0 && daten.image1_url ) {
+		        $('imageContactDetailTd').className = "";
+		        if(!$('imageContactDetailTd').firstChild) {
+		        	// TODO Why? (appears unnecessary)
+		        	$('imageContactDetailTd').appendChild(document.createElement("img"));
+		        }
+		        $('imageContactDetailTd').firstChild.src = daten.image1_url + "&timestamp=" + (daten.image_last_modified||0);
+		    } else {
+		    	// dummy picture
+		        if(!$('imageContactDetailTd').firstChild) {
+		        	// TODO Why? (appears unnecessary)			        	
+		        	$('imageContactDetailTd').appendChild(document.createElement("img"));
+		        }
+		        $('imageContactDetailTd').className = "contactDummyImage border-color-default";
+		        $('imageContactDetailTd').firstChild.className="border-color-content-default";
+		        $('imageContactDetailTd').firstChild.src = getFullImgSrc('img/contacts/dummypicture.gif');
+		    }                                                   
+						
 			var telephone_business1 = daten['telephone_business1'] || "";
 			var telephone_business2 = daten['telephone_business2'] || "";
 			var telephone_company = daten['telephone_company'] || "";
@@ -2024,12 +2048,15 @@ function initLiveGridOnLoad()
 	contactGrid.getTable(list);
 		
 	contactGrid.events.register("Selected", 
-		function(ids){
-			triggerEvent("Selected",contactGrid.selection.getSelected());
+		function(ids) {
 			setStatusDLSelection();
 		}
 	);
 	
+	function setStatusDLSelection_db() {
+		triggerEvent("Selected", contactGrid.selection.getSelected());
+	}
+	
 	contactGrid.events.register("Activated", function(ids) {
 			if(ids && ids.length > 0) {
 				if(menuhasRight(ids,"WRITE")) {
