@@ -419,11 +419,16 @@ function initContactContent() {
 	addDOMEvent($("last_name"), "keyup", autofillDN);
 	addDOMEvent($("first_name"), "keyup", autofillDN);			
 	addDOMEvent($("last_name"), "mouseout", autofillDN);
-	addDOMEvent($("first_name"), "mouseout", autofillDN);	
+	addDOMEvent($("first_name"), "mouseout", autofillDN);
+	
+	if (clickedItemForSave == 6) {
+		$("email1").disabled = true;
+		$("email1").removeAttribute("onkeydown");
+	}
+	
 	window.setTimeout(function() {
 		  oMainFolderTree.get_folder_path(clickedItemForSave, cb_getpath);		
-	   },0);
-	
+	   },0);	
     setTabLists(tabsList, panelsList, eventList);
     window.setTimeout(function() {
             triggerEvent("OX_Switch_View","contact_new/business");
@@ -687,6 +692,12 @@ function autofillDN() {
 	}
 }
 
+function autofillDN_turn_off(e) {
+	if (!e) e = window.event;
+	// turn off autocomplete only if characters are entered
+	// ignores control, alt, shift, tab, etc.
+	if (e.keyCode >= 32) autofillmatch = false;
+}
 
 /********************************** Save Contact *****************************************************************/
 /**
@@ -1122,7 +1133,7 @@ function writeNewContact()
 			json.value = JSON.serialize(contact_object);		
 			submit();
 		}				
-	} else {
+	} else {		
 		json.put(AjaxRoot + "/contacts?action=new&session=" + session +"&folder="+clickedItemForSave+ "&" , contact_object, null, 
 		function(idObj){
 			if(idObj) {	
@@ -1156,8 +1167,12 @@ function finalFunction(myObject)
        corewindow.OXContactMapping.createObject(contact_object);
        corewindow.closeContactPopUp(window, clickedItemForSave);
     } else if(modulPopup = "edit") {
-       setBeforeUnload(false);
-       corewindow.OXContactMapping.editObjects([dataFromDb.data],contact_object);
+        setBeforeUnload(false);
+        corewindow.OXCache.newRequest(null, "contacts", { columns: [],
+            objects: [corewindow.OXContactMapping.createKeyFromObject({
+                module: "contacts", folder_id: clickedItemForSave,
+                id: contactDetailId
+            })] }, null, emptyFunction, true);
        corewindow.closeContactPopUp(window, clickedItemForSave);
     }
 	
