@@ -575,7 +575,6 @@ Accordion.getHeight = function(node,accordion,maximumheight) {
 	return value;
 }
 
-
 function createHoverContent(innerwidth,headerheight,borderheight,imgsizes, tabnummer) {
 	var mywidth=412;
 	var innerwidthtop;
@@ -666,141 +665,165 @@ function createHoverContent(innerwidth,headerheight,borderheight,imgsizes, tabnu
 	return returnobj;
 }
 
-/* ################################################################################################# */
+/* ########################################## TABS ####################################################### */
 
-function Tabbing(count, tabnummer) {
-
-    this.content;
-    this.mousedownactive=false;
-    this.selected=0;
-    this.tabbingwidth=410;
-	this.tabsize = { h : 19, w : 105 };
-    this.count=count;
-    this.tabnummer = tabnummer;
-    
-    this.tabbingcontents=new Array();
-    for(var i=0;i<count;i++) {
-        this.tabbingcontents[i]=new Object();
-        this.tabbingcontents[i]["active"]=false;
-    }
+/**
+ * tab container
+ * @param id {String} the id of the hover which the tab container is attached to (deprecated)
+ */
+function Tabbing(id) {
+	// @TODO: the id is just a workaround for the 'broken by design' hover layout
+	// and needs to be reviewed!
+	this.id = id;
+	this.tabs = new Array();
+	this.selected; 
 }
 
-Tabbing.prototype.getDomNode = function(type) {
-	switch(type){
-		default:
-			return this.getDomNodeType1();
-	}
-}
-
-Tabbing.prototype.setNodeFunctions =function(i,enable,disable,title) {
-	if(i>=0 && this.tabbingcontents.length > i) {
-
-		if (this.content.getElementsByTagName("td")[i].firstChild){
-			var todelete = this.content.getElementsByTagName("td")[i].firstChild;
-			this.content.getElementsByTagName("td")[i].removeChild(todelete);
-		}
-	
-		this.tabbingcontents[i].enable=enable;
-		this.tabbingcontents[i].disable=disable;
-		this.tabbingcontents[i].title=title;
-		title = typeof title == "string" ? document.createTextNode(title) : title;
-				
-		this.content.getElementsByTagName("td")[i].appendChild(title);
+Tabbing.prototype = {
 		
-		if (i > 0){
-			var prevElement = this.content.getElementsByTagName("td")[(i-1)];
-			this.content.getElementsByTagName("td")[i]
+	/**
+	 * returns the DOMNode containing all tabs
+	 * @returns {DOMNode} the DOMNode containing all tabs
+	 */
+	getDOMNode: function() {
+		var Self = this;
+		
+		var trnode = newnode("tr");
+		for (var i in this.tabs) {			
+			var tdnode = this.tabs[i].getDOMNode();
+			trnode.appendChild(tdnode);
 		}
+		
+		trnode.appendChild(
+				newnode("td", { width : "100%" }, 
+					{ className : "tabbing_border_style" }, 
+					[ document.createTextNode("\u00a0")] ) 
+				);
+		
+		return trnode;
+	},
 
-	}
-}
-
-Tabbing.prototype.getDomNodeType1 = function() {
-	var Self=this;
-	if(this.content) {
-		return this.content;
-	}
-
-	var tabcounts = [];
-	var leftStartPosition;
-
-	for (var i = 0; i < this.tabbingcontents.length; i++){
-		tabcounts[i] = newnode("td", { }, { className : "clickable hover_master_background tabbing_tab_inactive" }, []);
-	}
+	/**
+	 * adds a new tab with the given id
+	 * @param tab {Tab} the tab
+	 */
+	addTab : function(tab) {
+		 var Self = this;	
+		 if (this.tabs.length == 0) {
+			tab.select(true);
+			this.selected = 0;
+		 }
+		 this.tabs.push(tab);	
+		 
+		 // attach click event to td - do we have to unregister this event?!?
+		 addDOMEvent(tab.getDOMNode(), "click", 
+			(function(id, pos) {
+				return function(e) {
+					Self.selectTabById(id);
+				}
+			})(tab.id)
+		);		
+	},
 	
-	tabcounts[tabcounts.length] = newnode("td", { width : "100%" }, { className : "tabbing_border_style" }, [document.createTextNode("\u00a0")]);
-	this.content = newnode("tr",{},{},tabcounts);
-	addDOMEvent(this.content,"click",function (e) { Self.click(e) });
+	/**
+	 * removes a tab with the given id
+	 * @param id {String} the id of the tab
+	 */
+	removeTab : function(id) {
+		for (var i in this.tabs) {
+			if (this.tabs[i].id == id) {
+				this.tabs.splice(i,i);
+			}
+		}
+	},
 	
-	return this.content;
-}
-
-Tabbing.prototype.nodeClicked = function(pos,force,selected,sliderstep) {
-	if(!selected) { 
-		selected=pos
-		this.selected=pos;
-	}
-	if (this.tabbingcontents[selected]){
-		this.selected = selected;
-		if(this.tabbingcontents[selected]["active"]) {
-			if(force) { this.enableButton();	}
+	selectTabById : function(id) {
+		var pos = 0;
+		// iterate through tabs and select / deselect them
+		for (var i in this.tabs) {
+			if (id == this.tabs[i].id) {
+				this.selected = pos = i;
+			}
+			this.tabs[i].select(id == this.tabs[i].id);
+		}
+		
+		// do we have to trigger a callback?
+		if (this.tabs[this.selected].onShow) {
+			this.tabs[this.selected].onShow();
+		}
+		
+		// ugly hack to fix the 'broken by design' hover layout
+		// hover layout needs to be reviewed (again) :-|
+		if (this.selected == 0) {
+			// change bg image on left corner of hover if first tab is selected
+			$ALL(this.id + "hover-tabbin-corner-l").className = "hover_master_background hover-header-tab-tl_ac";
 		} else {
-			this.enableButton();
+			// change bg image on left corner of hover if first tab is selected
+			$ALL(this.id + "hover-tabbin-corner-l").className = "hover_master_background hover-header-tab-tl";
+			// change the bg image of the td on the left of the selected td
+			this.tabs[this.selected-1].getDOMNode().className="hover_master_background tabbing_tab_inactive_left";
 		}
-	} else {
-		this.selected=0;
-		this.enableButton();
+	},
+	
+	/**
+	 * returns the requested {Tab} tab
+	 * @param id {String} the id of the tab
+	 * @returns {Tab} the tab object, otherwise null
+	 */
+	getTabById : function(id) {
+		for (var i in this.tabs) {
+			if (this.tabs[i].id == id) {
+				return this.tabs[i];
+			}
+		}	
+		return null;
 	}
 	
 }
 
-Tabbing.prototype.enableButton = function() {
-    
-	this.tabbingcontents[this.selected]["active"]=true;
-	this.content.getElementsByTagName("td")[this.selected].className="hover_master_background tabbing_tab_active";
+/**
+* a single tab
+* @param id {String} the id of the tab
+* @param title {String} the tab title
+* @param onShow {function} a function called when entering the tab
+*/
+function Tab(id, title, onShow) {
+	this.id = id;
+	this.title = title;
+	this.onShow = onShow;
+	this.enabled = true;
+	this.node = newnode("td", 0, 
+			{ className : "clickable hover_master_background tabbing_tab_inactive" }, 
+			[ addTranslated(title) ]);
+}
 
+Tab.prototype = {
+	/**
+	 * show / hide the tab
+	 * @param {boolean} enabled - true shows the tab, otherwise false
+	 */
+	show : function(enabled) {
+		this.enabled = enabled;
+		this.node.style.display = this.enabled ? "" : "none";
+	},
 	
-	for(var i=0;i<this.tabbingcontents.length;i++) {
-	   if(i!=this.selected) {
-	       this.tabbingcontents[i]["active"]=false;
-	       this.tabbingcontents[i]["title"].parentNode.className="hover_master_background tabbing_tab_inactive";
-	   }
-	}
-
-	if (this.selected > 0){
-	    this.tabbingcontents[this.selected-1]["title"].parentNode.className="hover_master_background tabbing_tab_inactive_left";
-	}
-
-
-	if (this.selected == 0){
-    	document.getElementById(this.tabnummer+"hover-tabbin-corner-l").className="hover_master_background hover-header-tab-tl_ac";
-	} else {
-    	document.getElementById(this.tabnummer+"hover-tabbin-corner-l").className="hover_master_background hover-header-tab-tl";
-	}
-		
-		
-    if(this.tabbingcontents[this.selected].enable) {
-		this.tabbingcontents[this.selected].enable();
+	/**
+	 * selects / highlights the tab
+	 * @param {boolean} selected - true select the tab, otherwise false
+	 */
+	select : function(selected) {
+		this.node.className = selected ? "hover_master_background tabbing_tab_active" : "hover_master_background tabbing_tab_inactive";
+	},
+	
+	setTitle : function(title) {
+		this.node.firstChild.nodeValue = title;
+	},
+	
+	/**
+	 * returns the DOM node of the tab
+	 * returns {DOMNode} the dom node of the tab
+	 */
+	getDOMNode : function() {
+		return this.node;
 	}
 }
-
-
-Tabbing.prototype.getSelected = function() {
-    return this.selected;
-}
-
-Tabbing.prototype.click= function(e) {
-
-    var posx=getAbsolutePositionLeft(this.content);
-    var fieldposx=e.clientX-posx;
-    var opentab;
-    
-	for(var i=0;i<this.tabbingcontents.length;i++) {
-		if (fieldposx > this.tabbingcontents[i]["title"].parentNode.offsetLeft && fieldposx < ( this.tabbingcontents[i]["title"].parentNode.offsetLeft + this.tabbingcontents[i]["title"].parentNode.offsetWidth ) ){
-		    opentab = i;
-		}
-	}
-
-    this.selected = opentab;
-    this.nodeClicked(opentab,null);
-}
