@@ -919,75 +919,101 @@ function round(val) {
  * objective case (if true) or in nominative case (if false).
  */
 function getInterval(t, until) {
-    t = Math.round(t / 60000); // ms/min
-	if (t >= 10080 && t % 10080 == 0) { // min/week
-		var n = Math.round(t / 10080);
-		//#. Reminder (objective case): in X weeks
-        //#. %d is the number of weeks
-        //#, c-format
-        return format(until ? npgettext("in", "%d week", "%d weeks", n)
-        //#. General duration (nominative case): X weeks
-        //#. %d is the number of weeks
-        //#, c-format
-		                    :  ngettext(      "%d week", "%d weeks", n),
-		              n);
-	} else if (t >= 1440) {           // min/day
-		var n = Math.round(t / 1440);
-        //#. Reminder (objective case): in X days
-        //#. %d is the number of days
-        //#, c-format
-		return format(until ? npgettext("in", "%d day", "%d days", n)
-        //#. General duration (nominative case): X days
-        //#. %d is the number of days
-        //#, c-format
-		                    :  ngettext(      "%d day", "%d days", n),
-		              n);
-	} else if (t >= 60) {           // min/h
-		var h = Math.floor(t / 60);
-		var m = t % 60;
-        if (m) {
+    function minutes(m) {
+        return format(until
+            //#. Reminder (objective case): in X minutes
+            //#. %d is the number of minutes
+            //#, c-format
+            ? npgettext("in", "%d minute", "%d minutes", m)
+            //#. General duration (nominative case): X minutes
+            //#. %d is the number of minutes
+            //#, c-format
+            :  ngettext("%d minute", "%d minutes", m),
+            m);
+    }
+    function get_h(h) {
+        return format(until
+            //#. Reminder (objective case): in X hours
+            //#. %d is the number of hours
+            //#, c-format
+            ? npgettext("in", "%d hour", "%d hours", h)
+            //#. General duration (nominative case): X hours
+            //#. %d is the number of hours
+            //#, c-format
+            :  ngettext(      "%d hour", "%d hours", h),
+            h);
+    }
+    function get_hm(h, m) {
+        return format(until
             //#. Reminder (objective case): in X hours and Y minutes
             //#. %1$d is the number of hours
             //#. %2$s is the text for the remainder of the last hour
             //#, c-format
-    		return format(until ? npgettext("in", "%1$d hour and %2$s", "%1$d hours and %2$s", h)
+            ? npgettext("in", "%1$d hour and %2$s", "%1$d hours and %2$s", h)
             //#. General duration (nominative case): X hours and Y minutes
             //#. %1$d is the number of hours
             //#. %2$s is the text for the remainder of the last hour
             //#, c-format
-    		                    :  ngettext(      "%1$d hour and %2$s", "%1$d hours and %2$s", h),
-    		              h,
-            //#. Reminder (objective case): in X minutes
-            //#. %d is the number of minutes
+            :  ngettext("%1$d hour and %2$s", "%1$d hours and %2$s", h),
+            h, minutes(m));
+    }
+    function hours(t) {
+        if (t < 60) return minutes(t); // min/h
+        var h = Math.floor(t / 60);
+        var m = t % 60;
+        return m ? get_hm(h, m) : get_h(h);
+    }
+    function get_d(d) {
+        return format(until
+            //#. Reminder (objective case): in X days
+            //#. %d is the number of days
             //#, c-format
-    		              format(until ? npgettext("in", "%d minute", "%d minutes", m)
-            //#. General duration (nominative case): X minutes
-            //#. %d is the number of minutes
+            ? npgettext("in", "%d day", "%d days", d)
+            //#. General duration (nominative case): X days
+            //#. %d is the number of days
             //#, c-format
-    			                       :  ngettext(      "%d minute", "%d minutes", m),
-    			                 m));
-        } else {
-            //#. Reminder (objective case): in X hours
-            //#. %d is the number of hours
+            : ngettext("%d day", "%d days", d),
+            d);
+    }
+    function get_dhm(d, t) {
+        return format(until
+            //#. Reminder (objective case): in X days, Y hours and Z minutes
+            //#. %1$d is the number of days
+            //#. %2$s is the text for the remainder of the last day
             //#, c-format
-            return format(until ? npgettext("in", "%d hour", "%d hours", h)
-            //#. General duration (nominative case): X hours
-            //#. %d is the number of hours
+            ? npgettext("in", "%1$d day, %2$s", "%1$d days, %2$s", d)
+            //#. General duration (nominative case): X days, Y hours and Z minutes
+            //#. %1$d is the number of days
+            //#. %2$s is the text for the remainder of the last day
             //#, c-format
-                                :  ngettext(      "%d hour", "%d hours", h),
-                          h);
-        }
+            : ngettext("%1$d day, %2$s", "%1$d days, %2$s", d),
+            d, hours(t));
+    }
+    function days(t) {
+        if (t < 1440) return hours(t); // min/day
+        var d = Math.floor(t / 1440);
+        t = t % 1440;
+        return t ? get_dhm(d, t) : get_d(d); 
+    }
+    function get_w(w) {
+        return format(until
+            //#. Reminder (objective case): in X weeks
+            //#. %d is the number of weeks
+            //#, c-format
+            ? npgettext("in", "%d week", "%d weeks", w)
+            //#. General duration (nominative case): X weeks
+            //#. %d is the number of weeks
+            //#, c-format
+            : ngettext("%d week", "%d weeks", w),
+            w);
+    }
+
+    t = Math.round(t / 60000); // ms/min
+	if (t >= 10080 && t % 10080 == 0) { // min/week
+        return get_w(Math.round(t / 10080));
 	} else {
-        //#. Reminder (objective case): in X minutes
-        //#. %d is the number of minutes
-        //#, c-format
-		return format(until ? npgettext("in", "%d minute", "%d minutes", t)
-        //#. General duration (nominative case): X minutes
-        //#. %d is the number of minutes
-        //#, c-format
-		                    :  ngettext(      "%d minute", "%d minutes", t),
-		              t);
-	}
+        return days(t);
+    }
 }
 
 var currencies = [
