@@ -102,18 +102,14 @@ function enableInfostoreLoadingScreen(enabled) {
     }    
 }
 
-function openInfostoreFile(evt, sValueCl, nObjectIdCl) {
+function openInfostoreFile(evt, sValueCl, nObjectIdCl, triggerSave) {
     var sContentType = 'application/octet-stream';
     var sURL = AjaxRoot + '/infostore/' 
                 + encodeURIComponent(sValueCl)
                 + '?action=document&session=' + session
-                + '&content_type=' + encodeURIComponent(sContentType)
+                + (triggerSave ? '&content_type=' + encodeURIComponent(sContentType) : "")
                 + '&id=' + encodeURIComponent(nObjectIdCl);
-    if (IE6) {
-        newWindow(sURL, getWindowOptions());    
-    } else {
-        $("dlIframe").src = sURL;
-    }
+    newWindow(sURL, getWindowOptions(null, null, (!triggerSave ? "scrollbars=yes" : "")));
     stopEvent(evt);
 }
 
@@ -168,6 +164,15 @@ function updateInfostoreSplit(object) {
             case "filename":
                   if (!idvalue) continue;
                   removeChildNodes($("infosplit."+idfield));
+                  
+                  var oNodAncS = newnode("img", { paddingRight:"5px" },{ className: "cursorPointer", align:"absmiddle", src:getFullImgSrc("img/menu/attachment_save.gif") })
+                  oNodAncS.onclick = (function(idvalue, object) { 
+            	         return function(e) {
+            	         	openInfostoreFile(e || event, idvalue, object["id"], true);
+            	         } 
+    	          })(idvalue, object);
+	              $("infosplit."+idfield).appendChild(oNodAncS);
+                  
                   var oNodAnc = newnode("span", 0, {className:"linkstyle"},
                         [ document.createTextNode(idvalue) ]);                  
                   oNodAnc.onclick = (function(idvalue, object) { 
@@ -175,8 +180,9 @@ function updateInfostoreSplit(object) {
               	         	openInfostoreFile(e || event, idvalue, object["id"]);
               	         } 
       	          })(idvalue, object);
-                  $("infosplit."+idfield).appendChild(newnode("img", { paddingRight:"5px" },{ align:"absmiddle", src:getFullImgSrc("/img/mail/open_ISattachment.gif") }));          
+                  $("infosplit."+idfield).appendChild(newnode("img", { paddingRight:"5px" },{ align:"absmiddle", src:getFullImgSrc("img/mail/open_ISattachment.gif") }));
                   $("infosplit."+idfield).appendChild(oNodAnc);
+                  
                   $("infosplit.file_info").style.display="";
                   continue;
                   break;
@@ -492,8 +498,14 @@ function loadLiveGridInfoSplit() {
 		});
 		gridInfoSplit.events.register("Activated", function(ids){
 			if(ids && ids.length > 0) {
-				if(menucheckRight("WRITE") && (1 == menucountlockable+menucounteditable))
+				if(   menucheckRight("WRITE")
+                   && menucountlockable + menucounteditable == 1)
+                {
 					editItem();
+                } else {
+                    triggerEvent("OX_New_Error", 4,
+                        _("You do not have write permission for this object."));
+                }
 			} else {
 				triggerEvent("OX_Before_Create_InfoStore");
 			}
