@@ -91,6 +91,7 @@ registerView("infostore/list",
 			register("OX_InfoStore_Send_Attachment",infostore_sendAttachment);
 			register("OX_InfoStore_Send_Link",infostore_sendLink);
 			register("OX_InfoStore_Open_Attachment",openFileinInfoStore);
+            register("OX_InfoStore_Save_Attachment",saveFileinInfoStore);
         }, 
         function() {
 			unLoadLiveGridInfoList();
@@ -107,6 +108,7 @@ registerView("infostore/list",
 			unregister("OX_InfoStore_Send_Attachment",infostore_sendAttachment);
 			unregister("OX_InfoStore_Send_Link",infostore_sendLink);
 			unregister("OX_InfoStore_Open_Attachment",openFileinInfoStore);
+            unregister("OX_InfoStore_Save_Attachment",saveFileinInfoStore);
         },
         function() {
 			hideNode("infostore_list"); 
@@ -155,6 +157,7 @@ registerView("infostore/split",
             register("OX_InfoStore_Send_Attachment", infostore_sendAttachment);
             register("OX_InfoStore_Send_Link", infostore_sendLink);
             register("OX_InfoStore_Open_Attachment", openFileinInfoStore);  
+            register("OX_InfoStore_Save_Attachment", saveFileinInfoStore);  
         }, 
         function() {
             if (infostoreRequest) {
@@ -178,6 +181,7 @@ registerView("infostore/split",
             unregister("OX_InfoStore_Send_Attachment", infostore_sendAttachment);
             unregister("OX_InfoStore_Send_Link", infostore_sendLink);
             unregister("OX_InfoStore_Open_Attachment", openFileinInfoStore);
+            unregister("OX_InfoStore_Save_Attachment", saveFileinInfoStore);
         },
         function() {
             hideNode("infostore_split"); 
@@ -250,6 +254,16 @@ function infostore_setFocus(grid) {
 }
 	
 function openFileinInfoStore(objects) {     
+    for(var i in objects) { 
+        var sContentType = 'application/octet-stream';
+        var sURL = AjaxRoot + "/infostore/" + encodeURIComponent(objects[i].filename) 
+                    + "?action=document&session=" + session
+                    + '&id=' + encodeURIComponent(objects[i].id);
+        newWindow(sURL, getWindowOptions(null, null, "scrollbars=yes"));
+    }
+}
+
+function saveFileinInfoStore(objects) {     
     for(var i in objects) { 
         var sContentType = 'application/octet-stream';
         var sURL = AjaxRoot + "/infostore/" + encodeURIComponent(objects[i].filename) 
@@ -266,41 +280,6 @@ function jumpToInfoStoreConfiguration(divId) {
 	triggerEvent("OX_Switch_View","configuration/infostore/preferences");
 }
 
-function infostore_sendLink(obj) {
-	function cb_openWindow(arg) {
-		var editorEnabled = (!configGetKey("gui.mail.formatmessage").match(/text\/plain/i));
-		var oInfoMailObj = new Object();	
-		var content = "";
-		for (var indx=0;indx < arg.length;indx++) {
-			var obj = arg[indx].data;
-			oMainFolderTree.get_folder_path(obj.folder_id || obj.folder, function(fName) { 
-				var dLink = getDirectLinkLocal(obj);
-				if (!obj.id) {
-					dLink = dLink.replace(/[#&]i=([^#&]+)/, "");
-				}
-				if (obj.title) {
-				    content += pgettext("description", "Title") + ": " + obj.title + "<br/>";	
-				}				
-				content += _("Folder") + ": " + fName + "<br/>";
-                content += _("Direct link") + ": " + (editorEnabled ? "<a href=\""+dLink+"\">"+dLink+"</a>" : dLink) + "<br/>";
-                if (indx < arg.length) content += "<br/>";
-			});		
-		}
-		oInfoMailObj["content"] = content;
-		oInfoMailObj["content_type"] = "text/plain";
-		var newMail = newWindow("newMail.html", getWindowOptions());
-
-		if (newMail) {
-			newMail.window.aInfoMailAttachmentLink = new Array(oInfoMailObj);
-		}
-	}
-	if (obj) {
-		cb_openWindow(obj);
-	} else { 
-		doAjaxGetInfoItemMulti(oLastSelectedInfoObject,cb_openWindow);
-	}
-}
-
 function infostore_sendAttachment(bSendAsLink) {	
 	function cb_openWindow(arg) {	
 		var aInfoMailObj = new Array();
