@@ -447,7 +447,7 @@ LiveGrid.prototype = {
 			table.appendChild(tbody);
 			parent.appendChild(table);
 			if(trs.length==0) {
-				return; 
+				//return; 
 			} 
 			cb();
 		}
@@ -1386,7 +1386,7 @@ LiveGrid2.prototype = {
                 columns : tmpColumns
             },null,function callback(data) {
 				if (!data || !data.objects) {
-					return;
+					//return;
 				}
 				for(var i=0;i<data.objects.length;i++) {
 					var obj=data.objects[i];
@@ -1412,7 +1412,7 @@ LiveGrid2.prototype = {
                  table.appendChild(tbody);
                  parent.appendChild(table);
                  if(trs.length==0) {
-                    return; 
+                    //return; 
                  }
                  cb();
             }
