@@ -116,6 +116,15 @@ register("OX_Mail_Delete",
                     ]);
 		}
 	);
+register("OX_Mail_SaveMail", 
+		function() {
+			var tF = parent.frames["mail.detail.pop.attachment.save"];	
+			var n_url = AjaxRoot + '/mail?action=get'
+				+ '&session=' + session + '&folder=' + encodeURIComponent(url["folder"])
+				+ '&id=' + encodeURIComponent(url["id"]);
+			tF.location.href=n_url+"&src=1&save=1";
+		}
+	);	
 register("OX_NEW_MAIL", function(){ newMail(""); });
 register("OX_Mail_Reply", function(){ newMail("reply"); });
 register("OX_Mail_ReplyAll", function(){ newMail("replyall"); });
