@@ -28,6 +28,43 @@ var detailrequest;
 var deleteMailIDs = emptyFunction;
 var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
 
+function infostore_sendLink(obj) {
+    function cb_openWindow(arg) {
+        var editorEnabled = (!configGetKey("gui.mail.formatmessage").match(/text\/plain/i));
+        var oInfoMailObj = new Object();    
+        var content = "";
+        var subject = "";
+        for (var indx=0;indx < arg.length;indx++) {
+            var obj = arg[indx].data;
+            oMainFolderTree.get_folder_path(obj.folder_id || obj.folder, function(fName) { 
+                var dLink = getDirectLinkLocal(obj);
+                if (!obj.id) {
+                    dLink = dLink.replace(/[#&]i=([^#&]+)/, "");
+                }
+                if (obj.title) {
+                    content += pgettext("description", "Title") + ": " + obj.title + "<br/>";   
+                    if (arg.length == 1) subject = obj.title;
+                }               
+                content += _("Folder") + ": " + fName + "<br/>";
+                content += _("Direct link") + ": " + (editorEnabled ? "<a href=\""+dLink+"\">"+dLink+"</a>" : dLink) + "<br/>";
+                if (indx < arg.length) content += "<br/>";
+            });     
+        }
+        oInfoMailObj["content"] = content;
+        oInfoMailObj["content_type"] = "text/plain";
+        var newMail = newWindow("newMail.html#subject="+encodeURIComponent(subject), getWindowOptions());
+
+        if (newMail) {
+            newMail.window.aInfoMailAttachmentLink = new Array(oInfoMailObj);
+        }
+    }
+    if (obj) {
+        cb_openWindow(obj);
+    } else { 
+        doAjaxGetInfoItemMulti(oLastSelectedInfoObject,cb_openWindow);
+    }
+}
+
 (function() {
 	var mailSelection = new Selection2();
 		
@@ -196,6 +233,15 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
 			deleteMails(activefolder, view.grid.getSelectedIDs());
 		}
 	);
+	register("OX_Mail_SaveMail", 
+		function() {
+			var tF = $("mail." + view.name + ".attachment.save");	
+			var n_url = AjaxRoot + '/mail?action=get'
+				+ '&session=' + session + '&folder=' + encodeURIComponent( activefolder )
+				+ '&id=' + encodeURIComponent(view.grid.getSelectedIDs()[0].id);
+			tF.src = n_url+"&src=1&save=1";
+		}
+	);
 	register("OX_Attachment_Open", function(){ if (activemodule == "mail") openAttachment("OPEN"); });
 	register("OX_Attachment_Open_Nested", function(){ if (activemodule == "mail") openNestedMessage(); });
 	register("OX_Attachment_Save", function(){ if (activemodule == "mail") openAttachment("SAVE"); });
@@ -586,6 +632,10 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
 	            view.grid.focus = index ? index-1 : 0;	            
 	        } else if (changed) {
 	        	var index = view.grid.focus || 0;
+	        	if (index >= view.grid.collection.objects.length) {
+	        		index--;
+	        	}
+	        	view.grid.focus = index;
 	        	view.grid.selection.click(index);
 	        }
 	        view.grid.showFocus();
@@ -1043,23 +1093,17 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
 	function deleteMails(folder, ids, harddelete) {			
         // return if ids is empty or a delete is still in progress
         if (!ids || ids.length == 0) return;
-        var index = view.grid.collection.getIndex(ids[0]) || 0;
-        var cb = (function(index) {
-        	return function() {
-        		if (!view.grid.collection.objects.length) return;
-        		view.grid.focus = index;
-        		view.grid.selection.click(index);
-        		//view.grid.showFocus();
-        	}
-        })(index-1);
-		
+        if (view.grid.focus) {
+        	view.grid.focus -= ids.length-1;      
+        }
+        
 		if (harddelete || configGetKey("mail.deletemail") || configGetKey("mail.folder.trash") == folder) {
             newConfirm(_("Delete E-Mails"),_('Are you sure you want to delete the selected E-Mails?'),AlertPopup.YESNO,null,null,
             function () {
-                OXMailMapping.deleteObjects(ids,true,cb)
+                OXMailMapping.deleteObjects(ids,true,emptyFunction)
             }, null);
 		} else {
-            OXMailMapping.deleteObjects(ids,false,cb);
+            OXMailMapping.deleteObjects(ids,false,emptyFunction);
 		}
 	}
 	
@@ -1118,7 +1162,7 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
     var oldMessageTextType=null;
 	var oldView=null;
 	function showMessage(view, message, folder) {
-        var attachExists = false, nested_msgs = "", selAttachment = null;		
+        var attachExists = false, nested_msgs = null, selAttachment = null;		
 		if (view != oldView) {
             oldMessage=null, oldMessageTextType=null;
         }
@@ -1284,56 +1328,57 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
                         removeChildNodes(mda);
                     }
                 }               
-            }       
-		}
+            }
+		
+			if (nested_msgs && nested_msgs != null) {	
+			    $("mail." + view.name + ".detail.content").style.visibility="hidden";
+				mailtextchanged=true;
+				for (var nMessage = 0; nMessage < nested_msgs.length; nMessage++) {
+					(function(o) {
+						var oNestedMessage = new Array(nested_msgs[o]);
+						var textAttachment = addTranslated(nested_msgs[o].filename || nested_msgs[o].subject || "message/rfc822 Part" );
+						var blank = document.createTextNode(" ");
+						var oDOMDiv = newnode("div", 0, { className: "mailDetailAttachmentsCont" },
+							[ newnode("img",0,{ src: getFullImgSrc("img/mail/unread.gif"), align: "top", title: textAttachment.data, padding: "3px"}),
+							  	newnode("span",0,{className: "_nothing"},
+							  		[ blank ]
+							  	),
+							  	newnode("span", 0, {className: "_nothing", title: textAttachment.data },
+							  		[ textAttachment ]
+							  	),
+							]
+						);
+						(function(oDOMDiv, selNested_msgs) {
+	                        addDOMEvent(oDOMDiv, "mousedown", function(e) {
+								selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
+								detailNestedMessage = selNested_msgs;
+								detailNestedMessage.sid = o;
+							});
+	                        addDOMEvent(oDOMDiv, "contextmenu", function(e) {
+	                            stopEvent(e);
+	                            selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
+	                            detailNestedMessage = selNested_msgs;
+	                            detailNestedMessage.sid = o;
+	                            globalContextMenus.attachments.display(e.clientX,
+	                                                                   e.clientY);
+	                        });
+	    					addDOMEvent(oDOMDiv, "dblclick", function(e) {
+								cancelBubbling(e);	
+								detailNestedMessage = selNested_msgs;
+								detailNestedMessage.sid = o;
+								openNestedMessage();	
+							});
+	    					if (menucountsubselected == 0) {
+	                        	selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
+	                        	detailNestedMessage = selNested_msgs;
+								detailNestedMessage.sid = o;
+	                        }
+						})(oDOMDiv, oNestedMessage);
+						mda.appendChild(oDOMDiv);
+					})(nMessage)
+				}	
+			}
 		
-		if (nested_msgs && nested_msgs != "") {	
-		    $("mail." + view.name + ".detail.content").style.visibility="hidden";
-			mailtextchanged=true;
-			for(var nMessage = 0; nMessage < nested_msgs.length; nMessage++) {
-				(function(o) {
-					var oNestedMessage = new Array(nested_msgs[o]);
-					var textAttachment = addTranslated(nested_msgs[o].filename || nested_msgs[o].subject || "message/rfc822 Part" );
-					var blank = document.createTextNode(" ");
-					var oDOMDiv = newnode("div", 0, { className: "mailDetailAttachmentsCont" },
-						[ newnode("img",0,{ src: getFullImgSrc("img/mail/unread.gif"), align: "top", title: textAttachment.data, padding: "3px"}),
-						  	newnode("span",0,{className: "_nothing"},
-						  		[ blank ]
-						  	),
-						  	newnode("span", 0, {className: "_nothing", title: textAttachment.data },
-						  		[ textAttachment ]
-						  	),
-						]
-					);
-					(function(oDOMDiv, selNested_msgs) {
-                        addDOMEvent(oDOMDiv, "mousedown", function(e) {
-							selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
-							detailNestedMessage = selNested_msgs;
-							detailNestedMessage.sid = nMessage;
-						});
-                        addDOMEvent(oDOMDiv, "contextmenu", function(e) {
-                            stopEvent(e);
-                            selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
-                            detailNestedMessage = selNested_msgs;
-                            detailNestedMessage.sid = nMessage;
-                            globalContextMenus.attachments.display(e.clientX,
-                                                                   e.clientY);
-                        });
-    					addDOMEvent(oDOMDiv, "dblclick", function(e) {
-							cancelBubbling(e);	
-							detailNestedMessage = selNested_msgs;
-							detailNestedMessage.sid = nMessage;
-							openNestedMessage();	
-						});
-    					if (menucountsubselected == 0) {
-                        	selectAttachment(oDOMDiv, selNested_msgs.length ? selNested_msgs[0] : selNested_msgs);
-                        	detailNestedMessage = selNested_msgs;
-							detailNestedMessage.sid = nMessage;
-                        }
-					})(oDOMDiv, oNestedMessage);
-					mda.appendChild(oDOMDiv);
-				})(nMessage)
-			}	
 		}
 		
         // do we have to enable pishing protection?
@@ -1360,19 +1405,24 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
 			$("mail."+view.name+".detail.header.image_protection").style.display="none";
 		}
 		
+		// get frame
+		var ih = getFrameElement("mail." + view.name + ".detail.content");
+		var ihf = ih;
+		
 		// set attachment display
 		if (mailtextchanged) {
 			$("mail." + view.name + ".detail.content").style.visibility = "hidden";			
 			view.setAttachments(attachExists);
-			var ih = getFrameElement("mail." + view.name + ".detail.content");			
 			if (ih && ih.document) {
 				ih = ih.document;
 				ih.open();
-				ih.writeln(cnn);
+				// safari needs explicit head/body "around" the content
+				ih.writeln("<html><head><title></title></head><body>" + cnn + "</body></html>");
 				ih.close();
 				setTimeout(function(){	
                     var head = ih.getElementsByTagName("head");
 					if (head && head.length) {
+						// would not work for safari without explicit head tag
 						head[0].appendChild(				   
 					       newnode("link", null,{ type: "text/css", rel: "stylesheet", href: "themes/"+configGetKey("gui.theme").path+"/css/iframe.css" }, null, ih));
 					}
@@ -1380,9 +1430,15 @@ var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
 						ih.getElementsByTagName("body")[0].style.margin=".5em";
 					} catch (e) { }
 					parseDirectLinksInMails(ih);
+					// reset scroll position
+					if (ihf) ihf.scrollTo(0,0);
 				}, 0);
 			}
+		} else {
+			// reset scroll position
+			if (ihf) ihf.scrollTo(0,0);
 		}
+
         // do we have to send a disposition notification?
 		if (!oldMessage || !equals(message["id"], oldMessage["id"])) {
 			var dm = message["disp_notification_to"];
