@@ -22,7 +22,7 @@ var configGetKey = corewindow.configGetKey;
 var configSetKey = corewindow.configSetKey;
 var options = configGetKey("gui.mail.newmail_options") || { "from": true, "cc": true, "bcc": false, "options": false };
 var editorEnabled = (!configGetKey("gui.mail.formatmessage").match(/text\/plain/i));
-
+var allowHTML = configGetKey("gui.mail.htmlmessage");
 /**
  * callback when tinyMCE get initialized
  */
@@ -66,7 +66,7 @@ tinyMCE.init({
 	
 	gecko_spellcheck : true,	
 	button_tile_map : true,
-	entity_encoding: "raw",
+	entity_encoding: "numeric", // lately changed from "raw" to "numeric"
 	relative_urls : false,
 	convert_urls : false,
 	
@@ -81,8 +81,9 @@ tinyMCE.init({
 	
 	convert_fonts_to_spans : false,
 	
-    setup: function(ed) { ed.onKeyPress.add(tinyKeypress); }
-
+    setup: function(ed) {
+		ed.onKeyPress.add(tinyKeypress);
+	}
 });
 
 function tinyKeypress(ed, e) {
@@ -100,7 +101,7 @@ function tinyKeypress(ed, e) {
                     if (container.nodeName.toUpperCase() == "BLOCKQUOTE")
                         break SearchBlockquotes;
                     container = container.parentNode;
-                }
+                }xec
                 return;
             }
             var container = range.commonAncestorContainer;
@@ -249,6 +250,7 @@ function newMailWindowOnload() {
  * contents for the new mail window 
  */
 function newMailOnload() {
+	
 	loadingComplete();
 	
 	/*
@@ -259,9 +261,10 @@ function newMailOnload() {
         img[i].src = img[i].src.replace(/\/default\//g, "/"+themeStyle.path+"/")
     }
     */
-	triggerEvent("OX_Switch_View","mail_new");	
-	triggerEvent("OX_menu_Change_Height",true);
-
+	
+	triggerEvent("OX_Switch_View", "mail_new");
+	triggerEvent("OX_menu_Change_Height", true);
+	
 	internalCache = corewindow.internalCache;
 	action = url["action"];
 	
@@ -278,7 +281,7 @@ function newMailOnload() {
 	for (var i in options) {
 	   triggerEvent("OX_New_Mail_Show_Additional_Header", i, options[i]);
 	}	
-	
+
 	/*
 	 * register to reszing event for setting the new height of the tinyMCE editor
 	 * when the user resizes the window 
@@ -297,17 +300,14 @@ function newMailOnload() {
 	else if (url["subject"])
 		setSubject(url["subject"]);
 	
-	var myFields = new Array("to", "cc", "bcc");
-	
 	/* 
 	 * init Addressbook
 	 */
-	if(!myListAddressBook) {
-		myListAddressBook = new SearchListAddressBook(null, "addressbookNewEmail", "newmailSearchResult", null, "newmail_add_list", "newmail_search", myFields);
-        myListAddressBook.setAllFolders($("newmail-search-all-folders"),
-                                        $("but_folder"));
-	}
-	myListAddressBook.buildFloatingDiv("none");		
+	if(!myListAddressBook) {		
+		setTimeout("initAddressBook()", 250);
+	} else {
+		setTimeout("myListAddressBook.buildFloatingDiv('none')", 250);
+	}	
 	
 	// disable attachments first
 	triggerEvent("SubSelected", 0);
@@ -325,35 +325,32 @@ function newMailOnload() {
 	if (!isNaN(configGetKey("gui.mail.auto_save_drafts")) && configGetKey("gui.mail.auto_save_drafts") != 0) {
 		window.setInterval("oMailFunctionsNew.autosaveMessage()", ( configGetKey("gui.mail.auto_save_drafts") * 60000 ));	
 	}
-	
+}
+
+function initAddressBook() {
+	var myFields = new Array("to", "cc", "bcc");
+	myListAddressBook = new SearchListAddressBook(
+			null, "addressbookNewEmail", "newmailSearchResult", 
+			null, "newmail_add_list", "newmail_search", myFields
+			);
+    myListAddressBook.setAllFolders(
+    		$("newmail-search-all-folders"), $("but_folder")
+    		);
+    myListAddressBook.buildFloatingDiv('none');
 }
 
 registerView("mail_new", null, 
 			function() {
-				try{
-					if (url["action"] && (url["action"] == "reply" || url["action"] == "replyall")){
-						tinyMCE.execCommand('mceAddControl', true, 'editor_content');
-						tinyMCE.execCommand('mceFocus', true, 'editor_content');						
-					} else {
-						setTimeout(function() { if ($("to") && $("to").focus()) $("to").focus(); }, 0);					
-					}
-				} catch(e) { }
+				// set focus
+				setInitialFocus();
 			}, null,
 			function() {
 				unregister("cb_mailComboChanged", cb_mailComboChanged);
 			},
 			function() {
-				try{
-					if (url["action"] && (url["action"] == "reply" || url["action"] == "replyall")){
-						tinyMCE.execCommand('mceAddControl', true, 'editor_content');
-						tinyMCE.execCommand('mceFocus', true, 'editor_content');
-					} else {
-						setTimeout(function() { if ($("to") && $("to").focus()) $("to").focus(); }, 0);					
-					}
-				} catch(e) { }
+				// set focus
+				setInitialFocus();
 			}
-			
-
 		);
 
 /**
@@ -392,29 +389,136 @@ function cb_deleteAttachments() {
 
 register("setSignature", cb_setSignatureText);
 function cb_setSignatureText(obj) {
-	if(obj) {		
-		obj.signature_text = obj.signature_text.replace(/\n/g,"<br/>");
-		var text = tinyMCE.activeEditor.getContent();
-		if(obj.position == "above") {			
-			var newText = "<span>" + replaceLeadingSpaces(obj.signature_text) + "</span><br/><br/>" + text;
-		} else if(obj.position == "below") {			
-			var newText = text + "<br/><br/><span>" + replaceLeadingSpaces(obj.signature_text) + "</span>";
+
+	// shortcut to active editor / body
+	var ae = tinyMCE.activeEditor;
+	var docBody = ae.getBody();
+	
+	// always remove both placeholders now
+	// first, remove preceding BR of top signature
+	var adjacentBRTop = ae.dom.select("br + #mceSignatureTop");
+	if (adjacentBRTop.length) {
+		ae.dom.remove(getPreviousSibling(adjacentBRTop[0]));
+	}
+	// now remove placeholders
+	ae.dom.remove('mceSignatureTop');
+	ae.dom.remove('mceSignatureBottom');
+	
+	// position == "none"? (obj is null if no signature is selected)
+	if (!obj) return;
+	
+	// prepare signature
+	// replace newlines in signature
+	obj.signature_text = obj.signature_text.replace(/\n/g, "<br/>");
+	var signature_text = replaceLeadingSpaces(obj.signature_text);
+	
+	// position?
+	switch(obj.position) {
+	
+		case "above":
+			// add preceding BR
+			var newElement = ae.dom.create('br');
+			// use workaround to add node
+			addBeforeOrBottom(ae, newElement, "mcePresetContent");
+			// add new DOM node
+			var newElement = ae.dom.create('span', {
+				id : 'mceSignatureTop',
+				style: 'font-family: monospace' // important if "allow html" is on
+				}, '');
+			// use workaround to add node
+			addBeforeOrBottom(ae, newElement, "mcePresetContent");
+			// create snippet
+			var signature_snippet = "" + signature_text + "<br/>";
+			// add via DOM (via id - not DOM node - would not work as expected)
+			ae.dom.setHTML("mceSignatureTop", signature_snippet);
+			break;
+
+		case "below":
+			// no break
+		default:
+			// second BR?
+			var secondBR = endsWithBR(docBody) ? "" : "<br/>";
+			// add new DOM node
+			var newElement = ae.dom.create('span', {
+				id : 'mceSignatureBottom',
+				style: 'font-family: monospace' // important if "allow html" is on
+				}, '');
+			docBody.insertBefore(newElement, null);
+			// create snippet
+			var signature_snippet = "<br/>" + secondBR + signature_text;
+			// add via DOM (via id - not DOM node - would not work as expected)
+			ae.dom.setHTML("mceSignatureBottom", signature_snippet);
+			break;
+	}
+}
+
+// workarond for safari in order to avoid its NOT_FOUND_ERR (DOM Exception 8)
+function addBeforeOrBottom(activeEditor, newNode, existingNodeId) {
+	try {
+		// get document
+		var doc = activeEditor.getWin().document;
+		var docBody = activeEditor.getBody();
+		// get existing Node
+		var existingNode = doc.getElementById(existingNodeId);
+		if (existingNode) {
+			// has BR before?
+			var pSib = getPreviousSibling(existingNode);
+			if (pSib && pSib.nodeName == "BR") {
+				existingNode = pSib;
+			}
+			// add node
+			existingNode.parentNode.insertBefore(newNode, existingNode);
 		} else {
-			var newText = text + "<br/><br/><span" + replaceLeadingSpaces(obj.signature_text) + "</span>";
+			// add at bottom
+			docBody.insertBefore(newNode, null);
 		}
-		tinyMCE.activeEditor.setContent(newText);
-//		window.setTimeout(
-//			function() {
-//				tinyMCE.activeEditor.setContent(newText); 
-//			}, 0);
+	} catch(e) { }
+}
+
+// get previous element sibling of a DOM node (skips e.g. text nodes)
+function getPreviousSibling(node) {
+	var sib = node;
+	while (sib) {
+		sib = sib.previousSibling;
+		if (sib && sib.nodeType == 1) break;
+	}
+	return sib;
+}
+
+// checks whether the last node of the editor is a line break (BR)
+// required for correct handling of bottom signatures
+function endsWithBR(container) {
+	var index = container.childNodes.length-1;
+	var node = container.childNodes[index];
+	while (node) {
+		if (node.nodeType == 1) {
+			return node.nodeName == "BR" ? true : false;
+		}
+		index--;
+		node = container.childNodes[index];
+	}
+}
+
+function replaceEditorContent(newText) {
+	// replace editor content (this way does not overwrite the clipboard)
+	var contentBody = tinyMCE.activeEditor.dom.select("body");
+	// has body?
+	if (contentBody.length > 0) {
+		// yes - replace and return new content
+		tinyMCE.activeEditor.dom.setHTML(contentBody[0], newText);
+		return newText;
+	} else {
+		// no - return previous content
+		return tinyMCE.activeEditor.getContent();
 	}
 }
 
 function initMessageHeader() {
+	
 	var aliases = {};
 	for (var i=0; configContainsKey("mail.addresses") && i<configGetKey("mail.addresses").length; i++) {
 		aliases[configGetKey("mail.addresses")[i]] = configGetKey("mail.addresses")[i];
-	}	
+	}
 	
 	// adding e-mail addresses from external accounts to sender addresses list
 	if (corewindow.mail_accounts && corewindow.mail_accounts.ids.length) {
@@ -441,7 +545,11 @@ function initMessageHeader() {
     priority.onShow = function() { toggleSelectFields("hidden"); }
     priority.onHide = function() { toggleSelectFields("visible"); }
 	
-	signature = new ComboBox3(window, "mail.signatureCombo", "15em", 0, true, "setSignature", 2);
+    // get number of signatures (+1 = "None")
+    var signature_count = configGetKey("gui.mail.signatures").length + 1;
+    // add combobox (height depends on number of signatures (max 4 rows)
+	signature = new ComboBox3(window, "mail.signatureCombo", "15em", 0, true, "setSignature", Math.min(signature_count, 5));
+	// fill combobox
 	if(configContainsKey("gui.mail.signatures")) {
 		signature.addElement("None","");
 		for (var a=0; a < configGetKey("gui.mail.signatures").length; a++) {
@@ -519,7 +627,7 @@ function initMessageContent(m_action) {
 				function(cb) {
 					// disable loading screen
                     $("loading_data_bg").style.display="none";
-                    // mail no longer exists so shwo alert and then close window
+                    // mail no longer exists so show alert and then close window
 					if (cb && cb.code == "MSG-0032") {
 						newAlert(_("Error"), formatError(cb), 
 								function() { 
@@ -586,7 +694,7 @@ function setMessageText(attachments) {
 			} else { 
 				cnn += con;
 			}
-		} else {	
+		} else {
 		 	if(conArr["filename"] && !oMailFunctionsNew.attachmentExists(conArr.id)) {
 				oMailFunctionsNew.addAttachment(
 					{id: conArr.id || null, filename: conArr.filename || null, 
@@ -597,46 +705,106 @@ function setMessageText(attachments) {
 			}
 		}
 	}
-
-//	if (action != "draft")	{
-//		setTimeout(function() { 
-//			cb_setSignatureText(configGetKey("gui.mail.signatures")[defaultSignature]) 
-//		}, 0);
-//	}
 	
-	setTimeout(function() { 
-		tinyMCE.activeEditor.setContent(cnn);
-
-		if (action != "draft")	{
-			cb_setSignatureText(configGetKey("gui.mail.signatures")[defaultSignature]);
-		}
-
-		if (editorEnabled) { 
-			var default_font_tynmce = configGetKey("gui.mail.defaul_mail_font");
-			if (default_font_tynmce && default_font_tynmce != 'default'){ tinyMCE.execCommand('fontname',false,default_font_tynmce);  }
-
-			var default_font_size_tynmce = configGetKey("gui.mail.defaul_mail_font_size");
-			if (default_font_size_tynmce && default_font_size_tynmce != 'default'){ tinyMCE.execCommand('fontsize',false,default_font_size_tynmce);  }
-		
-			try{
-				//if (url["action"] && (url["action"] == "reply" || url["action"] == "replyall")){
-					tinyMCE.execCommand('mceAddControl', true, 'editor_content');
-					tinyMCE.execCommand('mceFocus', true, 'editor_content');
-				//} else {
-				//	setTimeout(function() { if ($("to") && $("to").focus()) $("to").focus(); }, 0);					
-				//}
-			} catch(e) { }
-		}
-		
-		// Other options which can be used here.
-		//tinyMCE.execCommand('Bold');
-		//tinyMCE.execCommand('mceInsertContent',false,'<b>Hello world!!</b>');
-		 	
-	}, 0);
-
+	// clear editor now & set content
+	// prevents messing up the editor on page reload (e.g., by pressing F5)
+	replaceEditorContent(
+			"<br/><br/><span id='mcePresetContent'>" + 
+			cnn.replace(/^<br\s*\/>/, '') + 
+			"</span>"
+		);
 	
+	if (action != "draft")	{
+		// set signature
+		cb_setSignatureText(configGetKey("gui.mail.signatures")[defaultSignature]);
+	}
+	
+	// reselect all content and reset cursor position to top
+	tinyMCE.activeEditor.selection.select(tinyMCE.activeEditor.dom.select("body")[0]);
+	tinyMCE.activeEditor.selection.collapse(true);
+
+	// enabled?
+	if (editorEnabled) {
+		try {
+			// add control
+			tinyMCE.execCommand('mceAddControl', true, 'editor_content');
+			// set default font
+			setDefaultFont();			
+			// set focus
+			setInitialFocus();
+			// Done!
+		} catch(e) { }
+	}
 }
 
+function isSafari() { return navigator.userAgent.indexOf("AppleWebKit") >= 0; }
+
+function setInitialFocus() {
+
+	// safari needs help to correctly set the focus on the editor 
+	// when pressing tab to jump from "subject" to "body"
+	var setting_focus = false;
+	if (isSafari()) {
+		addDOMEvent(tinyMCE.activeEditor.getWin(), "focus", function() {
+			// (explicit) set focus on the editor
+			if (!setting_focus) {
+				setting_focus = true;
+				tinyMCE.execCommand('mceFocus', true, 'editor_content');
+				setting_focus = false;
+			}
+		});
+	}
+	
+	// who needs the focus?
+	if (url["action"] != "reply" && url["action"] != "replyall") {
+		// set focus on "To" field
+		window.focus();
+		$("to").focus(); // ok for FF and IE
+		$("to").select(); // safari needs this
+	} else {
+		// set focus on the editor
+		tinyMCE.execCommand('mceFocus', true, 'editor_content');
+	}
+}
+
+function setDefaultFont() {
+	
+	try {
+		// safari needs little help to set font family and size
+		// If no content is given, safari does not apply such defaults
+		if (isSafari()) {
+		
+			// 1. add dummy content &#8203; (zero width char.)
+			var dummyContent = "<span>&#8203;</span>";
+			tinyMCE.execCommand('mceInsertContent', false, dummyContent);
+			
+			// 2. select this dummy content
+			var selector = "span";
+			tinyMCE.activeEditor.selection.select(tinyMCE.activeEditor.dom.select(selector)[0]);
+		}	
+		
+		// now set default font...
+		var default_font_tynmce = configGetKey("gui.mail.defaul_mail_font");
+		if (default_font_tynmce && default_font_tynmce != 'default') { 
+			tinyMCE.execCommand('FontName', false, default_font_tynmce);
+		}
+	
+		// ...and default size
+		var default_font_size_tynmce = configGetKey("gui.mail.defaul_mail_font_size");
+		if (default_font_size_tynmce && default_font_size_tynmce != 'default') {
+			tinyMCE.execCommand('FontSize', false, default_font_size_tynmce);
+		}
+		
+		if (isSafari()) {
+			// 3. collapse selection and put the focus on the editor
+			tinyMCE.activeEditor.selection.collapse(true);
+			tinyMCE.execCommand('mceFocus', false, 'editor_content');
+		}
+		
+	} catch(e) { }
+}
+
+
 function MailFunctions() {
 	this.oo = new Object();
 	this.ooA = new Object();
@@ -651,7 +819,7 @@ MailFunctions.prototype = {
 		var Self = this;	
         if (this.savePending) return;
 		if (!param) { 
-            Self.getMailValues(); 
+            Self.getMailValues();
         }
 		function cb_ok() {
 			Self.savePending = true;
@@ -715,6 +883,21 @@ MailFunctions.prototype = {
 		}
 	},
 	
+	getEditorContent: function() {
+		
+		// clean up editor's content
+		// must be done with a plain copy of the editor's content
+		// since auto-save comes around here (so do not work directly on the DOM!)
+		var editorContent = tinyMCE.activeEditor.getContent();
+		// 1. remove signature id
+		editorContent = editorContent.replace("id='mceSignatureTop'", '');
+		editorContent = editorContent.replace("id='mceSignatureBottom'", '');
+		// 2. remove special char (needed for safari)
+		editorContent = editorContent.replace(/&#8203;/g, '');
+		
+		return editorContent;
+	},
+	
 	getMailValues : function() {		
 		this.clearObjectContent();
 
@@ -742,8 +925,10 @@ MailFunctions.prototype = {
 		if(document.getElementsByName("mail.attachVCard")[0].checked)
 			this.oo["vcard"] = 1;
 	
+		// get content type
 		this.ooA["content_type"] = configGetKey("gui.mail.formatmessage");
-		this.ooA["content"] = tinyMCE.activeEditor.getContent();
+		// get content
+		this.ooA["content"] = this.getEditorContent();
 			
 		// build the final attachment object
 		var tmp_attachObj = new Array();
@@ -965,7 +1150,7 @@ function addAllnewmailToList() {
 }
 
 function replaceLeadingSpaces(text) {
-	return text.replace(/(^|<br>)([ \t]+)|([ \t]{2,}|\t)/g,
+	return text.replace(/(^|<br\s*\/?>)([ \t]+)|([ \t]{2,}|\t)/g,
 		function(_, prefix, m1, m2) {
 			var match = (m1 || m2).replace(/\t/g, "        "); // TODO: real tabs
 			var retval = new Array((match.length + 3) >> 1);
