@@ -163,7 +163,7 @@ var allcontentspicturepopup=new Array();     /* Alle Contents der Picture Popups
 
 var menu_modules=new Array();
 
-var menuminiteration = 3;
+var menuminiteration = 2;
 var menuiterationheight=1.6;
 var menupadding=0.4;
 var menumaxiteration=6;		
@@ -172,7 +172,7 @@ var menuiteration=4;
 var menupictureiterationmin=3;
 var menupictureiterationheight=menupictureiterationmin-1;
 
-var headerheight=1.5;		 /* Mindesth?he menu in Zeilen */
+var headerheight=1.5;		 /* min. height of each panel row */
 var arrowheight=0.7;
 var erroriteration=2;
 var menuerrorheight=1.6;
@@ -707,6 +707,39 @@ function menuinit(newmodule)
 		$("menu_search_global_searchfield").onmousedown = function () {
 			menumousedown=true;
 		}
+        globalSearchMenu = new PulldownMenu($("menu_search_context"));
+        /**
+         * Populates the pulldown menu with available search fields.
+         * @param {Array} fields An array of strings which specify
+         * the machine-readable field names (e. g. as used in the HTTP API).
+         * When this parameter not present or an empty array, the pulldown
+         * arrow is hidden.
+         * @param {Array} names An array of I18nString objects which specify
+         * the human-readable field names. Each entry corresponds to one in
+         * <code>fields</code>.
+         * @param {Object} checked An optional set of initially active fields.
+         * Each member corresponds to and has the same name as an entry in
+         * <code>fields</code>. The values are booleans. Defaults to all false.
+         */
+        globalSearchMenu.setFields = function(fields, names, checked) {
+            this.removeAllItems();
+            if (fields && fields.length) {
+                this.checked = checked;
+                for (var i = 0; i < fields.length; i++) {
+                    var item = new MenuItem(names[i], function() {
+                        globalSearchMenu.checked[this.searchField] =
+                            this.getChecked();
+                        globalSearchMenu.onChange();
+                    });
+                    item.searchField = fields[i];
+                    item.setChecked(globalSearchMenu.checked[fields[i]]);
+                    globalSearchMenu.addItem(item);
+                }
+                $("menu_search_context").style.display = "";
+            } else {
+                $("menu_search_context").style.display = "none";
+            }
+        }
 	} 
 	
 	register("OX_Configuration_Loaded", function(){
@@ -858,9 +891,6 @@ function showPanelHelp(myboolean)
 /************************* Error Panel*******************************************************************************/
 function addErrorMessage(priority,errormessage)
 {
-	if(priority==4) {
-		priority==2;
-	}
 	if(priority>0 && priority<5)
 	{
 		if(!errormessages[priority])
@@ -953,13 +983,12 @@ function showErrors1()
 }
 
 
-function changeClassAttributes(classname,element,value)
-{
-	 try {
-	 	//Check Browser
-	 	var pathtorules;
-	 	if (document.all) { pathtorules = 'rules'; }
-	 	else if (document.getElementById)  { pathtorules = 'cssRules'; }
+function changeClassAttributes(classname,element,value) {
+	try {
+		//Check Browser
+		var pathtorules;
+		if (document.all) { pathtorules = 'rules'; }
+		else if (document.getElementById)  { pathtorules = 'cssRules'; }
 		for(var i=0;i<document.styleSheets.length;i++) {
 			var item=document.styleSheets.item(i);
 			for(var i2=0;i2<item[pathtorules].length;i2++) {
@@ -973,49 +1002,40 @@ function changeClassAttributes(classname,element,value)
 }
 
 
-function afterLogin()
-{
-	new JSON().get("config/diemenu?session="+session,null,new function(reply)
-	{
-		if(reply)
-		{
-			if(reply.error)
-			{
+function afterLogin() {
+	
+	new JSON().get("config/diemenu?session="+session, null, new function(reply) {
+		if(reply) {
+			if(reply.error) {
 				alert(reply.error);
 			}
-			if (reply.oxlayout)
-			{
+			if (reply.oxlayout) {
 				oxlayout=reply.oxlayout;
 			}			
-		}
-		else
-		{
+		} else {
 			alert(_("No server connection"));
 		}
 	});
 }
 
-function changePopMenuModules(mymodule)
-{
-	for(zaehler in allcontentspicturepopup)
-	{
-		for (zaehler2 in allcontentspicturepopup[zaehler])
-		{
+function changePopMenuModules(mymodule) {
+	for(zaehler in allcontentspicturepopup) {
+		for (zaehler2 in allcontentspicturepopup[zaehler]) {
 			allcontentspicturepopup[zaehler][zaehler2].style.display="none";
 		}
 	}
-	for (zaehler2 in allcontentspicturepopup[mymodule])
-	{
+	for (zaehler2 in allcontentspicturepopup[mymodule]) {
 		allcontentspicturepopup[newmodule][zaehler2].style.display="block";
 	}
 }
+
 helpevents.register("help",doHelpMessage);
-function doHelpMessage(stringtoshow)
-{
+
+function doHelpMessage(stringtoshow){
 	$("menu_help_text").firstChild.nodeValue=stringtoshow;
 }
-function showPictureOptions()
-{
+
+function showPictureOptions() {
 	var hallo=$("menu_picture_pfeil_unten");
 	var mypopupmenu=$("menu_popup_picture");
 	mypopupmenu.style.top=(hallo.offsetTop+hallo.offsetHeight+3)+"px";
@@ -1024,142 +1044,143 @@ function showPictureOptions()
 	mypopupmenu.style.display="block";
 }
 
-function menuHeightChange(cancelHeightChange)
-{
+function menuHeightChange(cancelHeightChange) {
 	
-	if(menuiteration<menumaxiteration)
-	{
+	if(menuiteration<menumaxiteration) {
 		if(!cancelHeightChange) {
 			menuiteration++;
 		}
-		if(menuiteration==menumaxiteration)
-		{
+		if(menuiteration==menumaxiteration) {
 			$("menu_options_arrow_down").style.display="none";
 			$("menu_options_arrow_up").style.display="block";
 		}
-	}
-	else
-	{
+	} else {
 		if(!cancelHeightChange) {
 			menuiteration=menuminiteration;
 		}
 		$("menu_options_arrow_down").style.display="block";
 		$("menu_options_arrow_up").style.display="none";
 	}
-	try
-	{
+	try {
 		if(corewindow==window) { configSetKey("gui.menu.menuiteration",menuiteration); }
 		changeClassAttributes(".backgroundheight","height",((menuiteration*menuiterationheight)+(menupadding))+"em");
-	}
-	catch(e){}
+	} catch(e) {}
+	
 	triggerEvent("OX_menu_RESIZE");
 }
-function resizeMenuSplit()
-{
+
+function resizeMenuSplit() {
+	
 	var contentheight=(menuiteration*menuiterationheight+(menupadding));
+	
 	var helpheight=menuhelpheight;
-	if($("menu_help").style.display=="none")
-	{
+	if($("menu_help").style.display=="none") {
 		helpheight=0;
 	}
+	
 	var errorheight=erroriteration*menuerrorheight;
-	if($("menu_error").style.display=="none")
-	{
+	if($("menu_error").style.display=="none") {
 		errorheight=0;
 	}
+	
 	var h = (headerheight+arrowheight+contentheight+helpheight+errorheight+2)+"em";
-	try
-	{
+	try {
 		resizeSplit("all_of_menu", h); 
-	}
-	catch (e)
-	{}
+	} catch (e)	{}
 }
-function menuHeightChangePicture()
-{
+
+function menuHeightChangePicture() {
 	if(menuisActive("menu_picture")) {
 		fillsmallsymbols(menuiteration,activemodule);
 	}
 }
+
 register("OX_Switched",function() {
 	if(menuisActive("menu_picture")) {
 		fillsmallsymbols(menuiteration,activemodule);
-	}
+	}	
 });
+
 var modulesinpicturemenu=new Object();
-function fillsmallsymbols(iteration,mymodule)
-{
+function fillsmallsymbols(iteration,mymodule) {
+	
 	modulesinpicturemenu=new Object();
 	var zeigeobjekte=(iteration-3)*2
 	var zaehler=0;
-	var zeigepfeil=false;
-	for (zaehler1 in modules)
-	{
-		if(mymodule==modules[zaehler1]["name"])
-		{
-			if(document.getElementById("menu_small_"+modules[zaehler1]["name"]))
-			{
+	
+	for (zaehler1 in modules) {
+		if(mymodule==modules[zaehler1]["name"]) {
+			if(document.getElementById("menu_small_"+modules[zaehler1]["name"])) {
 				document.getElementById("menu_small_"+modules[zaehler1]["name"]).style.display="none";		
 				if(modules[zaehler1]["name"]=="contacts" && configGetKey("modules.contacts.module")) {
-					if(zaehler<zeigeobjekte) {
-						
+					if(zaehler<zeigeobjekte) {						
 						document.getElementById("menu_small_distributionlist").style.display="";		
 						zaehler++;					
-					}
-					else {
+					} else {
 						modulesinpicturemenu["distributionlist"]=true;
 						document.getElementById("menu_small_distributionlist").style.display="none";		
 					}
 				}
 			}
-		}
-		else
-		{
+		} else {
 			if(zaehler<zeigeobjekte) {
 				if($("menu_small_"+modules[zaehler1]["name"])) {
 					if(mymodule == "portal" && modules[zaehler1]["name"] == "mail") {
 						$("menu_small_"+modules[zaehler1]["name"]).style.display="none";	
-					}	
-					else {
+					} else {
 						if(configGetKey("modules."+modules[zaehler1]["name"]+".module")) {
 							$("menu_small_"+modules[zaehler1]["name"]).style.display="";		
 							zaehler++;
 							if(modules[zaehler1]["name"]=="contacts" && configGetKey("modules.contacts.module")) {
 								if(zaehler<zeigeobjekte) {
-									$("menu_small_distributionlist").style.display="";		
+									$("menu_small_distributionlist").style.display="";
 									zaehler++;					
-								}
-								else {
+								} else {
 									modulesinpicturemenu["distributionlist"]=true;
-									$("menu_small_distributionlist").style.display="none";		
+									$("menu_small_distributionlist").style.display="none";
 								}
 							}
 						} else {
-							$("menu_small_"+modules[zaehler1]["name"]).style.display="none";		
+							$("menu_small_"+modules[zaehler1]["name"]).style.display="none";
 						}
 					}
-					
 				}			
-			}
-			else
-			{
-				if($("menu_small_"+modules[zaehler1]["name"]))
-				{
+			} else {
+				if($("menu_small_"+modules[zaehler1]["name"])) {
 					if(modules[zaehler1]["name"]=="contacts") {
 						modulesinpicturemenu["distributionlist"]=true;
-						$("menu_small_distributionlist").style.display="none";		
+						$("menu_small_distributionlist").style.display="none";
 					}
 					modulesinpicturemenu[modules[zaehler1]["name"]]=true;
-					$("menu_small_"+modules[zaehler1]["name"]).style.display="none";		
-					zeigepfeil=true;
+					$("menu_small_"+modules[zaehler1]["name"]).style.display="none";
 				}	
 			}
 		}
 	}
+	
+	// count enabled modules
+	var enabled_modules = 0;
+	for (i = 0; i < modules.length; i++) {
+		switch(modules[i].name) {
+			case "contacts":
+				if (!modules[i].disable) enabled_modules++; // double
+				// nobreak
+			case "mail":
+			case "calendar":
+			case "tasks":
+			case "infostore":
+				if (!modules[i].disable) enabled_modules++;
+				break;
+		}
+	}
+	// show arrow?	
+	var zeigepfeil = enabled_modules > (iteration-3)*2+1;
+
 	$("menu_picture_normal").style.display = (zeigeobjekte == 0) ? "none" : "";
 	$("menu_picture_contextmenu_na").style.display= zeigepfeil ? "none" : "";
 	$("menu_picture_contextmenu").style.display= zeigepfeil ? "" : "none";
 }
+
 function reloadDynamicContent()
 {
 	setTimeout(function() { showElement(status_content,activemodule); },0);
