@@ -212,7 +212,13 @@ function MousePopup(node) {
                 body.onlosecapture = null;
                 body.releaseCapture();
             }
-            e.srcElement.fireEvent("on" + e.type);
+            switch (e.type) {
+                case "click":
+                    e.srcElement.click();
+                    break;
+                default:
+                    e.srcElement.fireEvent("on" + e.type);
+            }
             if (MousePopup.active) {
                 body.onlosecapture = MousePopup.hideActive;
                 body.setCapture();
@@ -446,13 +452,27 @@ function MenuItem(text, action) {
         { className: "PopupEntryDiv" },
         [newnode("span", 0, 0, [addTranslated(text)])]);
     addDOMEvent(this.node, "click", function(e) {
-        stopEvent(e);
-        if (Self.enabled) {
-            if (Self.action && Self.action() !== false)
-                Self.parent.close();
+        if (Self.checkbox) {
+            var target = e.target || e.srcElement;
+            if (target == Self.checkbox) {
+                cancelBubbling(e);
+                handleClick();
+            } else {
+                stopEvent(e);
+                Self.checkbox.click();
+            }
         } else {
-            if (Self.disabled_action && Self.disabled_action() !== false)
-                Self.parent.close();
+            stopEvent(e);
+            handleClick();
+        }
+        function handleClick() {
+            if (Self.enabled) {
+                if (Self.action && Self.action() !== false)
+                    Self.parent.close();
+            } else {
+                if (Self.disabled_action && Self.disabled_action() !== false)
+                    Self.parent.close();
+            }
         }
     });
     with (FSM) var transitions = [
@@ -513,15 +533,21 @@ MenuItem.prototype = {
     setIcon: function(icon, disabled_icon) {
         this.icon = icon;
         this.disabled_icon = disabled_icon;
-        if (this.img) {
-            this.img.src = this.getIcon();
-        } else {
-            this.img = newnode("img", {
-                position: "absolute", left: 0, top: 0, bottom: 0, margin: "auto"
-            }, { src: this.getIcon() });
-            this.node.insertBefore(this.img, this.node.firstChild);
+        if (icon) {
+            if (this.img) {
+                this.img.src = this.getIcon();
+            } else {
+                this.img = newnode("img", {
+                    position: "absolute", left: 0, top: 0, bottom: 0,
+                    margin: "auto"
+                }, { src: this.getIcon() });
+                this.node.insertBefore(this.img, this.node.firstChild);
+            }
+            if (this.parent) this.parent.iconAdded();
+        } else if (this.img) {
+            this.node.removeChild(this.img);
+            delete this.img;
         }
-        if (this.parent) this.parent.iconAdded();
         return this;
     },
     
@@ -565,6 +591,53 @@ MenuItem.prototype = {
         this.node.style.display = visible ? "" : "none";
     },
     
+    /**
+     * The current waiting status.
+     * @type Boolean
+     */
+    waiting: false,
+    
+    /**
+     * Sets the waiting status.
+     * When waiting, the menu item is shown as disabled, with an animated icon.
+     * @param {Boolean} waiting The new waiting status.
+     */
+    setWaiting: function(waiting) {
+        if (waiting == this.waiting) return;
+        this.waiting = waiting;
+        if (waiting) {
+            this.waitEnabled = this.enabled;
+            this.setEnabled(false);
+            this.waitSetEnabled = this.setEnabled;
+            this.setEnabled = function(enabled) { this.waitEnabled = enabled; };
+            this.waitIcon = this.icon;
+            this.waitDisabledIcon = this.disabled_icon;
+            this.setIcon("img/ox_animated_withoutbg.gif");
+        } else {
+            this.setEnabled = this.waitSetEnabled;
+            this.setEnabled(this.waitEnabled);
+            this.setIcon(this.waitIcon, this.waitDisabledIcon);
+            delete this.waitEnabled;
+            delete this.waitSetEnabled;
+            delete this.waitIcon;
+            delete this.waitDisabledIcon;
+        }
+    },
+    
+    /**
+     * Configures the menu item to automatically enter the waiting state when
+     * the enabled status cannot be computed from
+     * @param {Function} enableFunction A function which computes the enabled
+     * state of this menu item from Value objects.
+     */
+    setEnabledF: function(enableFunction) {
+        var Self = this;
+        Value.eval(enableFunction, function(wait, enable) {
+            if (!wait) Self.setEnabled(enable);
+            Self.setWaiting(wait);
+        });
+    },
+    
     /**
      * Returns the context in which this item is used. Usually, this is
      * the current selection for which a context menu is displayed.
@@ -573,6 +646,100 @@ MenuItem.prototype = {
     
 };
 
+/**
+ * Creates a new dynamic value.
+ * A dynamic value is a special object which works like a variable which
+ * contains the results of an asynchronous request and automatically updates
+ * calculations in which it is used when the request completes. The reason for
+ * using dynamic values instead of the Join class is that the results may be
+ * computed before the last request completes because some values are not needed
+ * e. g. (a && b) is false when a is false, regardless of the value of b.
+ *
+ * New dynamic values are created by calling the function Value():
+ * <code>var x = Value(), y = Value();</code>
+ * They can then be used in calculations by appending "()" to the variable
+ * names:
+ * <code>function calculation() { return x() > 3 && y() < 9; }</code>
+ * To enable automatic updates, the calculation function and a callback function
+ * which reacts to updates, are passed to Value.eval():
+ * <code>Value.eval(calculation, function(wait, result) { ... });</code>
+ * The callback function takes two parameters. The first parameter (wait) is
+ * true if the calculation could not be completed because some required dynamic
+ * values didn't receive their values yet. Otherwise, if the first parameter is
+ * false, then the second parameter (result) contains the result of
+ * the calculation.
+ *
+ * When a dynamic value becomes outdated, e. g. just before a new request is
+ * started to receive the new value, the old value must be cleared by calling
+ * the clear() method. When the request completes, the new value is set by
+ * calling the set() method:
+ * <code>
+ * x.clear();
+ * ox.JOSON.get(..., function(data) { x.set(...); });
+ * </code>
+ */
+function Value() {
+    var f = function() {
+        var e = Value.evaluations[Value.evaluations.length - 1];
+        f.callbacks[e.id] = e.callback;
+        if ("value" in f) return f.value; else throw Value.WaitException;
+    };
+    f.callbacks = {};
+    f.set = function(value) {
+        if (this.value == value) return;
+        this.value = value;
+        this.update();
+    };
+    f.clear = function() {
+        delete this.value;
+        this.update();
+    };
+    f.update = function() {
+        var callbacks = this.callbacks;
+        this.callbacks = {};
+        for (var i in callbacks) callbacks[i]();
+    };
+    return f;
+};
+
+Value.WaitException = {};
+
+Value.id = 0;
+
+Value.evaluations = [];
+
+/**
+ * Creates an automatically updated calculation.
+ * @param {Function} f A calculation function which uses dynamic values.
+ * @param {Function} callback A callback function which is called with one or
+ * two parameters: The first parameter is true when f throws Value.WaitException
+ * (usually a result of attempting to evaluate an empty dynamic value).
+ * The second parameter contains the return value of f and is present only when
+ * the first parameter is false.
+ */
+Value.eval = function(f, callback) {
+    var updatePending = false;
+    function delayUpdate() {
+        if (!updatePending) {
+            updatePending = true;
+            setTimeout(update, 0);
+        }
+    }
+    function update() {
+        updatePending = false;
+        Value.evaluations.push({ id: Value.id++, callback: delayUpdate });
+        try {
+            var result = f();
+            Value.evaluations.pop();
+            callback(false, result);
+        } catch (e) {
+            Value.evaluations.pop();
+            if (e == Value.WaitException) callback(true); else throw e;
+        }
+    }
+    update();
+};
+
 /**
  * A separator for popup menus. Can be used as a MenuItem most of the time, but
  * the only available method is setVisible.
