@@ -28,8 +28,14 @@
  * the DOM Event as parameter.
  */
 
-function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch, liveGridDivResult, divAddContact, searchField, moreFields)
-{
+function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch, liveGridDivResult, divAddContact, searchField, moreFields) {
+	// hack to hide the global address book
+	// use this with care! will be removed with upcomming releases!
+	if (new Boolean(configGetKey("modules.contacts.hideGlobalAddressBook")) == true &&
+		configGetKey("modules.infostore.module") == false) {
+		clickedItem = configGetKey("folder.contacts");
+		this.setAllFolders = function(){ };
+	}
 	var Self = this;
 	this.emptySearchText = _("Please enter your search");
 	this.searchField = searchField;
@@ -58,10 +64,7 @@ function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch
 	this.myAddedContacts = new AddedSearchContacts();
 	this.updateList = false;
 	this.tmpDistId = 210000000;
-	this.moreFields = new Array();
-	
-	if(moreFields)
-	this.moreFields = moreFields;
+	this.moreFields = moreFields || new Array();
 	this.method = "";
 	this.aFindedAddressboks = new Array();
 	this.recipientType = "to";	
@@ -669,12 +672,11 @@ AddedSearchContacts.prototype = {
 var contactAddressbookTreeLoaded = false;
 var treeAddressbookVisible = false;
 var newAddressbookFolderTree = null;
-var clickedItem = "";
+var clickedItem = 6;
 var currentDivIdForAddressbook = "";
 
 function addressbookFolderPath() {
-	//clickedItem = window.opener.configGetKey("folder.contacts");
-	clickedItem = 6;
+	//clickedItem = window.opener.configGetKey("folder.contacts");	
 	session = window.opener.session;
 	var folderViewSettingsNewContact = new Object();
 	var folderViewSettingsNewContactById = new Object();
