@@ -470,10 +470,6 @@ load_view : function (oFolders,attPoint,bReplace,bRootOnly){
 		if(this.selected_node != null && this.selected_node.id == sNodeDOMID) {
 			this.set_selected(oNode);
 		}
-		
-		if(oFolders.children[nFldr].children != null && !bRootOnly) {
-			this.load_view(oFolders.children[nFldr],oNode);
-		}
 	}
 	
 	var aNodesToRemove = new Array();
