@@ -21,6 +21,7 @@ var configfolder;
 var oMainFolderTree;
 var nSelectedIdStorage = null;
 var virtualFolderId = "__ox_virtualFolderNode";
+var importFolderDestination = null;
 
 function quickTreeUpdate() {
 	oMainFolderTree.update();
@@ -110,6 +111,29 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
             }
         });
     menu.addItem(link);
+
+    var import_data = new MenuItem("Import",
+			function() { 
+    			importFolderDestination = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
+    			triggerEvent("OX_Switch_View","configuration/import");
+    		});
+    menu.addItem(import_data);
+    
+	var export_submenu = new PopupMenu();
+    var export_submenu_vcard = new MenuItem("vCard", 
+            	function() { exportContacts(this.getContext().data, "VCARD");
+            	});
+   	export_submenu.addItem(export_submenu_vcard);
+
+    var export_submenu_csv = new MenuItem("CSV",
+    			function() { exportContacts(this.getContext().data, "CSV");
+    		});
+   	export_submenu.addItem(export_submenu_csv);
+
+    var export_contact = new MenuItem("Export", /*i18n*/
+    		export_submenu);
+    menu.addItem(export_contact);
+    
     
     menu.addItem(new MenuSeparator());
     
@@ -133,7 +157,7 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
         function() { contextAction(6, 0, this.getContext().data); });
     paste.setIcon("img/folder/pastefolder.gif", "img/folder/pastefolder_d.gif");
     menu.addItem(paste);
-    
+      
     menu.addItem(new MenuSeparator);
     
     var empty = new MenuItem("Empty folder", /*i18n*/
@@ -162,16 +186,23 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
                                  && String(oxfolder.id).match(/^default(\d+)?/))
                 ? "mail" : oxfolder.module;
             subscribe.setVisible(oxfolder.module == "mail");
-            link.setEnabled(oxfolder.own_rights & (127 << 7));
+            link.setEnabled(oxfolder.own_rights & (127 << 7) && oxfolder.module != "mail");
+            link.setVisible(!(oxfolder.module == "mail" || (oxfolder.module == "system" && this.context.type == "mail")));
             del.setEnabled(deleteAllowed(folder.oxfolder));
             rename.setEnabled(renamingAllowed(folder.oxfolder));
-            cut.setEnabled(del.enabled);
+            cut.setEnabled(del.enabled && (folderTreeFolderToMove == -1
+            				 || folderTreeFolderToMove != folder));
             paste.setEnabled(   folderTreeFolderToMove != -1
                              && moveAllowed(folderTreeFolderToMove.parent, 
                                             folderTreeFolderToMove, folder));
             empty.setVisible(   oxfolder.module == "mail"
                             && oxfolder.own_rights >> 21 & 127);
             sep1.setVisible(empty.visible);
+            
+            import_data.setEnabled((oxfolder.own_rights & 127) >= 2);
+            import_data.setVisible(oxfolder.module == "calendar" || oxfolder.module == "contacts" || oxfolder.module == "tasks");            
+            export_contact.setEnabled(oxfolder.type != 3 && oxfolder.module == "contacts");
+            export_contact.setVisible(!(oxfolder.module != "contacts" || oxfolder.type == 3));
         } else {
             new_folder.setEnabled(false);
             subscribe.setEnabled(false);
@@ -180,6 +211,8 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
             rename.setEnabled(false);
             cut.setEnabled(false);
             paste.setEnabled(false);
+            import_data.setEnabled(false);
+            export_contact.setEnabled(false);
             empty.setVisible(false);
             sep1.setVisible(false);
         }
@@ -341,7 +374,7 @@ function contextAction(nNumber,evt,node,type) {
 			insertFolder(node);
 			break;		
 		case 8:
-			emptyFolder(node);       							
+			emptyFolder(node);	   							
 	}
 }
 
@@ -638,4 +671,12 @@ function removeVirtualFolder(folderID) {
 	 return oMainFolderTree.delete_node(folderID);
 }
 
+function exportContacts(node, action){
+	var tF = $("dlIframe");	
+	var n_url = AjaxRoot + '/export?action=' + action
+		+ '&session=' + session
+		+ '&folder=' + oMainFolderTree.get_folder_by_node_id(node.id).oxfolder.data.id;
+	tF.src = n_url;
+}
+ 
 fileloaded();
\ No newline at end of file
