@@ -34,6 +34,7 @@ var tasksPanelsList;
 var tasksEventList;
 var attachmentWindow = 0;
 var taskTmpStorage;
+var latestRenderedTask = null;
 var objTaskDetailParticipants = null;
 var refTaskDetailParticipantTab = null;
 var taskParticipantsGrid = null;
@@ -74,8 +75,8 @@ function() {
         );        
     }
     registerView("tasks",
-            null, 
-            null,
+    		null,
+    		null,
             function() {
                 if (tmpDetailRequest) {
                     OXCache.unregister(tmpDetailRequest.uniqueName);
@@ -111,11 +112,11 @@ function() {
     );
     
     registerView("tasks/list",
-        function() { 
+        function() {
             showNode("taskslist");  
             $("taskslist").style.display=""; 
         }, 
-        function() {
+        function() {    	 	
             var criteria= { "folder_id" : activefolder };
             gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
             gridlist.enable(criteria);            
@@ -135,6 +136,7 @@ function() {
             unregister("OX_Print",printTasks);     
             unregister("OX_Delete_Search", taskSearchDelete);
             unregister("OX_Task_MarkAsDone", tasks_markAsDone);
+            latestRenderedTask=null;
          },
          function() { 
             hideNode("taskslist");  
@@ -152,20 +154,19 @@ function() {
     );
 	
     registerView("tasks/split",
-            function() { 
+            function() {
                 showNode("taskssplit");  
-                $("taskssplit").style.display=""; 
+                $("taskssplit").style.display="";
             }, 
-            function() {      	
+            function() {
                 setTabLists(tasksTabsList, tasksPanelsList, tasksEventList);
                 var criteria= { "folder_id" : activefolder };
                 gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
                 gridsplit.enable(criteria);                
-                // re-select id, if it's a direct link for example
-                if (activeTaskId.length && activeTaskId[0].directLink &&
-                    activeTaskId[0].id) {
+                // reselect id if it's a direct link for example
+                if (activeTaskId.length && activeTaskId[0].directLink && activeTaskId[0].id) {
                 	delete(activeTaskId[0].directLink);
-                    gridsplit.selection.selectIDs([ Key.createfromObject(activeTaskId[0]) ])                    
+                    gridsplit.selection.selectIDs([ Key.createfromObject(activeTaskId[0]) ]);
                 }
                 tasksFolderPath.drawDOMNode("taskofsplitview", activefolder);
                 expandTaskSplitHeader(configGetKey("gui.tasks.fullsplitheader"));
@@ -177,6 +178,8 @@ function() {
                 register("OX_Add_Flag", fn_add_Tag_tasks);
                 register("OX_Delete_Search", taskSearchDelete);
                 register("OX_Task_MarkAsDone", tasks_markAsDone);
+                // update confirm button
+                triggerEvent("Confirmation_Changed", 0);
              }, 
              function() {
              	tasksFolderPath.clear();          
@@ -198,27 +201,29 @@ function() {
                 hideNode("taskssplit");  
                 $("taskssplit").style.display="none";
              },
-             function(changeFolder) { 
-            	if (changeFolder != undefined) {
-                    var criteria= { "folder_id" : activefolder };
-                    gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
-                    gridsplit.enable(criteria,false);
-                    tasksFolderPath.drawDOMNode("taskofsplitview", activefolder);
-                    tasks_setFocus(gridlist);
-            	}
+             function(changeFolder) {
+				if (changeFolder != undefined) {
+				    var criteria= { "folder_id" : activefolder };
+					gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
+					gridsplit.enable(criteria,false);
+					tasksFolderPath.drawDOMNode("taskofsplitview", activefolder);
+					tasks_setFocus(gridlist);
+					// update confirm button
+					triggerEvent("Confirmation_Changed", 0);
+				}
              }
     );
     
     registerView("tasks/split/overview",
             function() {
                 $("tasktab1").style.display="block";
-                $("taskpanel1").className="tabbing_tab_active";     
+                $("taskpanel1").className="tabbing_tab_active";
             },
             null,
             null,
             function() {
                 $("tasktab1").style.display="none";
-                $("taskpanel1").className="tabbing_tab_inactive";       
+                $("taskpanel1").className="tabbing_tab_inactive";
             }
     );
     
@@ -235,7 +240,7 @@ function() {
             },
             function() {
                 $("tasktab2").style.display="none";
-                $("taskpanel2").className="tabbing_tab_inactive";        
+                $("taskpanel2").className="tabbing_tab_inactive";
             }
     );
     
@@ -268,7 +273,13 @@ function() {
         taskconfirm.showConfirmation(new AcceptDenyObject("tasks", completedetailtask));
     }
     
-    function cb_selection_changed() {  
+    function cb_selection_changed() {
+    	// get current task to prevent double selection (-> double rendering)
+        var currentTask = activeTaskId.length > 0 ? activeTaskId[0].id : null;
+        if (currentTask == latestRenderedTask) return;
+       	// remember current task
+        latestRenderedTask = currentTask;
+        // now process selection
     	if (!tasksSelection2.getSelected().length) return;
     	tasks_setFocus(gridsplit)         
         fn_tasks_getDetails(tasksSelection2.getSelected());        
@@ -449,7 +460,8 @@ function() {
 	        return checkbox;
 	    }
     	
-        var constructor= newlivegrid ? LiveGrid2 : LiveGrid; 
+        var me = configGetKey("identifier");
+        var constructor= newlivegrid ? LiveGrid2 : LiveGrid;
         var grid = new constructor([ 
             {
                 sortable: false,
@@ -486,6 +498,8 @@ function() {
                     if (!div.firstChild) div.appendChild(addCheckBox());
                     div.firstChild.style.display = "";
                     div.firstChild.checked = (data["percent_completed"] && data["percent_completed"] >= 100);
+                    div.firstChild.disabled =
+                        grid.write_own && (data.created_by != me);
                 },
                 clear: function(div) {
                     if (!div.firstChild) div.appendChild(addCheckBox());
@@ -656,25 +670,31 @@ function() {
         ], newlivegrid ? tasksSelection2 : tasksSelection , "tasks");
         
         var contextData = [];
+        var count = Value(), writable = Value(), deletable = Value();
+        var confirmable = Value();
         var menu = grid.contextmenu = globalContextMenus.tasks = new ContextMenu();
         
         var edit = new MenuItem("Edit", /*i18n*/
             function() { triggerEvent('OX_Task_Edit'); });
         edit.setIcon("img/menu/edit.gif", "img/menu/edit_d.gif");
+        edit.setEnabledF(function() { return count() == 1 && writable(); });
         menu.addItem(edit);
         
         var del = new MenuItem("Delete", /*i18n*/
             function() { triggerEvent('OX_Task_Delete'); });
         del.setIcon("img/menu/delete.gif", "img/menu/delete_d.gif");
+        del.setEnabledF(function() { return count() > 0 && deletable(); });
         menu.addItem(del);
         
         var copy = new MenuItem("Use as template", /*i18n*/
             function() { triggerEvent('OX_Task_Duplicate'); });
         copy.setIcon("img/menu/task_copy.gif", "img/menu/task_copy_d.gif");
+        copy.setEnabledF(function() { return count() == 1 && writable(); });
         menu.addItem(copy);
     
         var done = new MenuItem("Mark as Done", /*i18n*/
             function() { triggerEvent('OX_Task_MarkAsDone'); });
+        done.setEnabledF(function() { return count() > 0 && writable(); });
         menu.addItem(done);
         
         menu.addItem(new MenuSeparator());
@@ -684,42 +704,45 @@ function() {
         });
         confirm.setIcon("img/menu/global_confirmation_change.gif",
                         "img/menu/global_conf_change_d.gif");
+        confirm.setEnabledF(function() { 
+        	return count() > 0 && confirmable(); 
+        });
         menu.addItem(confirm);
     
-        var req;
         menu.onShow = function() {
-            var collection = {
-                columns: ["users", "created_by"],
-                objects: this.getContext().getSelected()
-            };
-            req = OXCache.newRequest(null, "tasks", collection,
-                                     responseData, responseData);
-            function responseData(data) {
+            var sel = this.getContext().getSelected();
+            count.set(sel.length);
+            writable.clear();
+            deletable.clear();
+            confirmable.clear();
+            if (!sel.length) return;
+
+            OXCache.newRequest(null, "tasks",
+                { columns: ["created_by"], objects: sel }, null, ownerData);
+            function ownerData(data) {
                 contextData = data.objects;
-                var count = 0;
-                for (var i in contextData) count++;
-                var writable = menuhasRight(contextData, "WRITE");
-                edit.setEnabled(count == 1 && writable);
-                del.setEnabled(count > 0 && menuhasRight(contextData, "DELETE"));
-                copy.setEnabled(count == 1 && writable);
-                done.setEnabled(count > 0 && writable);
-                var enableConfirm = false;
-                if (count > 0) {
-                    var me = configGetKey("identifier");
-                    for(var i in contextData) {
-                        var users = contextData[i].users;
+                writable.set(menuhasRight(contextData, "WRITE"));
+                deletable.set(menuhasRight(contextData, "DELETE"));
+            }
+
+            OXCache.newRequest(null, "tasks",
+                { columns: ["users"], objects: sel }, null, userData);
+            function userData(data) {
+                contextData = data.objects;
+                for(var i in contextData) {                	
+                    var users = contextData[i].users;
+                    var me = config.identifier;
+                    CheckUsers: {
                         for(var j = 0; j < users.length; j++) {
-                            if (users[j].id == me) {
-                                enableConfirm = true;
-                                break;
-                            } 
+                            if (users[j].id == me) break CheckUsers;
                         }
+                        confirmable.set(false);
+                        return;
                     }
                 }
-                confirm.setEnabled(enableConfirm);
+                confirmable.set(true);
             }
         };
-        menu.onHide = function() { OXCache.unregister(req.uniqueName); };
         
         grid.identification = gridName; 
         
@@ -845,7 +868,7 @@ function() {
     function printTasks() {
         if (!tasksSelection2 || activemodule != "tasks") {
         	return;
-        } else if (tasksSelection2.count > 1) {
+        } else if (tasksSelection2.count != 1) {
         	if (currentpath2[1] == "split" && gridsplit) {
         		globalprint.printLiveGrid(gridsplit);
         	} else if (gridlist) {
@@ -980,7 +1003,7 @@ function enableTaskLoadingScreen(enabled) {
 var aStatusTask = new Array("Not started","In progress","Done","Waiting","Deferred");
 function updateTaskSplit(object) {
     if (!object || activemodule != "tasks") return;
-	
+    
 	// changing the selection jumps back to overview tab
 	if (currentpath2[1] == "split" && currentpath2[2] != "overview") { 
         triggerEvent("OX_Switch_View", "tasks/split/overview");
@@ -1078,7 +1101,7 @@ function updateTaskSplit(object) {
                   objTaskDetailParticipants.popArray();
                   objTaskDetailParticipants.oParticipantResources = clone(idvalue);  
                   objTaskDetailParticipants.writeCountParticipants();
-                  objTaskDetailParticipants.pushArray();
+                  objTaskDetailParticipants.pushArray();	                  
                   $("tasks.split.participants_count").firstChild.data = objTaskDetailParticipants.arrayLength();
                   internalCache.getUsers(objTaskDetailParticipants.idUserArr,fnSetTaskUserColumn);
                   break;
@@ -1104,10 +1127,7 @@ function updateTaskSplit(object) {
                   break;
             case "actual_duration":
             case "target_duration":
-                  //#. General duration (nominative case): X minutes
-		          //#. %d is the number of minutes
-		          //#, c-format
-                  idvalue = idvalue ? format(ngettext("%d minute", "%d minutes", idvalue), idvalue)  : _("Not set");
+                  idvalue = idvalue ? getInterval(idvalue * 6e4 /* ms/min */) : _("Not set");
                   break;
             case "actual_costs":
             case "target_costs":
@@ -1444,13 +1464,14 @@ TaskDetailParticipantTab.prototype = {
     enableGrid : function () {
         this.appendToStorage();
         var tmp_participants = new Array()
-        for(var i = 0; i < objTaskDetailParticipants.gridData.length; i++){
+        for(var i = 0; i < objTaskDetailParticipants.gridData.length; i++) {
             tmp_participants[i] = objTaskDetailParticipants.gridData[i];
         }
         this.myTaskPStorage.append(tmp_participants);
         //enable the grid
-        if(taskParticipantsGrid)
-            taskParticipantsGrid.enable(this.myTaskPStorage); 
+        if(taskParticipantsGrid) {
+            taskParticipantsGrid.enable(this.myTaskPStorage);
+        }
     },
     
     disableGrid : function() {
@@ -1461,8 +1482,11 @@ TaskDetailParticipantTab.prototype = {
 }
 
 function fnSetTaskUserColumn(arg) {
-    if (arg) objTaskDetailParticipants.fnSetUserColumn(arg);
+    if (arg) {
+    	objTaskDetailParticipants.fnSetUserColumn(arg);
+    }
 }
+
 function fnSetTaskGroupColumn(arg) {
     objTaskDetailParticipants.fnSetGroupColumn(arg);
 }
